@@ -1,7 +1,7 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "الفِرَق",
+    "Teams" : "الفرق",
     "You created the team {circle}" : "لقد قُمت بإنشاء الفريق {circle}",
     "{author} created the team {circle}" : "{author} قام بإنشاء الفريق {circle}",
     "You deleted {circle}" : "أنت حذفت الدائرة {circle}",
@@ -55,7 +55,6 @@ OC.L10N.register(
     "On events happening in a <strong>team</strong> of which you are a member" : "تبعاً للأحداث التي تحدث في الفريق <strong></strong> الذي أنت عضو فيه",
     "Any important event in a <strong>team</strong> you are moderating" : "حدث هام في الفريق <strong></strong> الذي تتولى أنت التنسيق له",
     "On global events happening in any <strong>team</strong>" : "الأحداث العامة التي تحدث في أي فريق <strong></strong>",
-    "Shared to Circles" : "مُشتركٌ مع الدوائر",
     "Single" : "مُنفرِدٌ single",
     "Personal" : "شخصي",
     "System" : "النظام",
@@ -64,10 +63,10 @@ OC.L10N.register(
     "Invite" : "يدعو",
     "Join request" : "طلب انضمام",
     "Friends" : "الأصدقاء",
-    "Password protected" : "محمي بكلمة السر",
+    "Password protected" : "محمي بكلمة مرور",
     "No Owner" : "لا يوجد مالك",
     "Hidden" : "مخفي",
-    "Backend" : "جهة الخادوم",
+    "Backend" : "جهة الخادم",
     "Local" : "المحلي",
     "Root" : "الجذر",
     "Team invite" : "دعوة الفريق",
@@ -80,7 +79,7 @@ OC.L10N.register(
     "Circle" : "دائرة",
     "Nextcloud App" : "تطبيق نكست كلاود",
     "Member" : "عضو",
-    "Moderator" : "مُنسّق moderator",
+    "Moderator" : "مشرف",
     "Admin" : "مدير",
     "Owner" : "مالك",
     "%s shared »%s« with you." : "%s مُشتركة »%s« معك.",
@@ -106,29 +105,29 @@ OC.L10N.register(
     "Fresh installation status" : "حالة التنصيب الجديدة",
     "Building Local Database" : "بناء قاعدة بياناتٍ محلّيّةٍ",
     "Testing Basic Circle Creation" : "اختبار إنشاء دائرة أساسية basic circle",
-    "Adding local users and moderators" : "إضافة مُستخدَمين محلّيّين و مُنسِّقِين moderators",
-    "Show all teams" : "عرض كل الفِرَق",
+    "Adding local users and moderators" : "إضافة مستخدمين محليين ومشرفين",
+    "Show all teams" : "عرض كل الفرق",
     "Create a new team" : "إنشاء فريق جديد",
     "Files" : "الملفّات",
     "This feature is not available for personal circles" : "هذه الميزة غير مُتاحة في الدوائر الشخصية",
-    "The team is not federated" : "الفريق ليس اتحاديّاً",
+    "The team is not federated" : "الفريق ليس فريق من السحابة الموحدة",
     "You cannot join this team" : "لا يمكنك الانضمام إلى هذا الفريق",
-    "This member is not a moderator" : "هذا العضو ليس مُنسِّقاً",
+    "This member is not a moderator" : "هذا العضو ليس مشرف",
     "Insufficient privileges" : "الصلاحيات لا تكفي",
     "This member does not exist" : "هذا العضو غير موجود",
     "This member is the owner of the team" : "هذا العضو هو مالك الفريق",
     "Level cannot be changed for this type of member" : "لا يمكن تغيير المستوى لعضو من هذا النوع",
-    "You are already a member of this circle" : "أنت عضوُ في هذه الدائرة من قبل",
+    "You are already a member of this circle" : "أنت عضو في هذه الدائرة من قبل",
     "You have been blocked from this circle" : "أنت محظور من هذه الدائرة ",
     "The account is already a member of this circle" : "هذا الحساب عضوٌ في هذه الدائرة من قبل",
     "The account has already been invited into this circle" : "هذا الحساب تمّت دعوته لهذه الدائرة مُسبقاً",
     "%s (Team owned by %s)" : "%s (فريق يملكه %s)",
-    "You are now a member of the Circle \"%2$s\"" : "أنت الآن عضوٌ في الدائرة \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "لقد تمّت دعوتك من قِبَل %1$s إلى الدائرة \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s أرسل طلباً ليكون عضواً في الدائرة \"%2$s\"",
+    "You are now a member of the Team \"%2$s\"" : "أنت الآن عضو في الفريق \"%2$s\"",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "أنت مدعوٌ من قِبَل %1$s لعضوية الفريق \"%2$s\"",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s أرسل طلباً لعضوية الفريق \"%2$s\"",
     "Accept" : "قبول",
     "Refuse" : "رفض",
-    "Leave the circle" : "غادر الدائرة",
+    "Leave the team" : "مغادرة الفريق",
     "%s" : "%s",
     "Personal team" : "فريق شخصي",
     "%s owned by %s" : "%s يملكها %s",
@@ -141,60 +140,22 @@ OC.L10N.register(
     "Password to access content" : "كلمة مرورٍ للوصول إلى المحتوى",
     "This item is already shared with this team" : "هذا العنصر سبقت مشاركته سلفاً مع هذا الفريق",
     "Bring cloud-users closer together." : "تقريب مستخدمي السحابة من بعضهم البعض.",
-    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "تسمح الفِرَق للأشخاص بإنشاء مجموعاتهم الخاصة من الأشخاص/الزملاء/الأصدقاء. يمكن بعد ذلك استخدام هذه المجموعات من الأشخاص بواسطة أي تطبيق آخر لغرض المشاركة.",
+    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "تسمح الفرق للأشخاص بإنشاء مجموعاتهم الخاصة من الأشخاص/الزملاء/الأصدقاء. يمكن بعد ذلك استخدام هذه المجموعات من الأشخاص بواسطة أي تطبيق آخر لغرض المشاركة.",
     "No files in here" : "لا توجد ملفات هنا",
     "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
     "Name" : "الاسم",
     "Size" : "الحجم",
     "Modified" : "آخر تعديل",
-    "Circles" : "دوائر",
-    "Circles' files" : "ملفات الدوائر",
-    "Select circles to filter by" : "فلترة الدوائر على أساس",
-    "No circles found" : "لا توجد أي دوائر",
-    "Please select circles to filter by" : "رجاءً، اختر دوائر للفلترة على أساس",
-    "No files found for the selected circles" : "تعذّر العثور على أي ملفاتٍ للدوائر المُختارة",
-    "You created the circle {circle}" : "أنت أنشأت الدئرة {circle}",
-    "{author} created the circle {circle}" : "{author} أنشأ الدائرة {circle}",
-    "You added circle {member} as member to {circle}" : "أنت قمت بضم {member} كعضو في {circle}",
-    "{author} added circle {member} has been added as member to {circle}" : "{author} قام بإضافة الحلقة {member} كعضو في الحلقة {circle}",
-    "You removed {member} leave {circle}" : "أنت قمت بمنع {member} من مغادرة الحلقة {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "عند وقوع أحداث في <strong>دائرة</strong> أنت عضوٌ فيها",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "أيّ حدثٌ هامٌّ في <strong>دائرة</strong> أنت مُنسّقٌ moderator فيها",
-    "On global events happening in any <strong>Circle</strong>" : "عند وقوع أيّ حدث عامٍّ في أي <strong>دائرة</strong>",
-    "Join Request" : "طلب انضمام",
-    "Password Protected" : "محمي بكلمة المرور",
-    "Circle Invite" : "دعوة للدائرة",
-    "Email Address" : "عنوان البريد الالكتروني",
-    "Circle not found" : "تعذّر العثور على الدائرة",
-    "Circle not found " : "تعذّر العثور على الدائرة",
-    "This account is already a member of the circle" : "هذا الحساب عضوٌ في الدائرة مُسبقاً",
-    "Federated link not found" : "رابط اتحادي federated link غير موجود",
-    "The circle is not federated" : "الدائرة ليست اتحاديّةً",
-    "You cannot join this circle" : "لا يمكنك الانضمام إلى الحلقة",
-    "This member is the owner of the circle" : "هذا العضو هو مالك الدائرة",
-    "%s (Circle owned by %s)" : "%s (دائرة يملكها %s)",
-    "Personal Circle" : "دائرة شخصية",
-    "You need a specify a type of circle" : "يجب أن تُحدّد نوع الدائرة",
-    "A circle with that name exists" : "توجد دائرة بذات الاسم مُسبقاً",
-    "This member is not the owner of the circle" : "هذا العضو ليس هو مالك الدائرة",
-    "This member is not an admin of the circle" : "هذا العضو ليس مُشرفاً admin في الدائرة",
-    "Group contains too many members" : "تحوي المجموعة عدداً أكثر ممّا يجب من الأعضاء ",
-    "This group does not exist" : "هذه المجموعة غير موجودة",
-    "This group is already linked to the circle" : "هذه المجموعة مربوطةٌ مسبقاً بالدائرة",
-    "You cannot edit level in a personal circle" : "لا يُمكنك تعديل المستوى في دائرة شخصية",
-    "Group cannot be set as owner of a circle" : "لا يمكن تعيين مجموعةٍ كمالكٍ لدائرة",
-    "now" : "الآن",
-    "This account does not exist" : "هذا الحساب غير موجود",
-    "Email format is not valid" : "تنسيق الإيميل غير صحيحٍ",
-    "This contact is not available" : "جهة الاتصال هذه غير مُتاحةٍ",
-    "You have no permission to create a new circle" : "ليس عندك الصلاحية لإنشاء دائرةٍ جديدةٍ",
-    "This item is already shared with this circle" : "هذا العنصر سبق و أن تمّت مشاركته مع هذه الدائرة",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "تسمح \"الدوائر\" Circles للأشخاص بإنشاء مجموعات خاصة بهم من الزملاء و الأصدقاء. \nيمكن بعد ذلك استخدام هذه المجموعات من الأشخاص (أو \"الدوائر\") بواسطة أي تطبيق آخر لأغراض المشاركة.",
-    "Teams' files" : "ملفات الفِرَق",
-    "Select team to filter by" : "حدِّد فريقاً للفلترة بحسبه",
+    "Teams' files" : "ملفات الفرق",
+    "Select team to filter by" : "قم بتحديد فريق للتصفية بحسبه",
     "No teams found" : "لا يوجد أي فريق",
-    "Please select teams to filter by" : "رجاءً، حَدِّد فِرَقاً للفلترة بحسبها",
-    "No files found for the selected teams" : "لا توجد أي ملفات للفِرَق المحددة",
-    "{author} added team {member} has been added as member to {circle}" : "{author} قام بإضافة الفريق {member} كعضو في {circle}"
+    "Please select teams to filter by" : "رجاءً، قم تتحديد فرق للتصفية بحسبها",
+    "No files found for the selected teams" : "لا توجد أي ملفات للفرق المحددة",
+    "{author} added team {member} has been added as member to {circle}" : "{author} قام بإضافة الفريق {member} كعضو في {circle}",
+    "Shared to Circles" : "مُشتركٌ مع الدوائر",
+    "You are now a member of the Circle \"%2$s\"" : "أنت الآن عضوٌ في الدائرة \"%2$s\"",
+    "You have been invited by %1$s into the Circle \"%2$s\"" : "لقد تمّت دعوتك من قِبَل %1$s إلى الدائرة \"%2$s\"",
+    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s أرسل طلباً ليكون عضواً في الدائرة \"%2$s\"",
+    "Leave the circle" : "غادر الدائرة"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
