@@ -1,8 +1,8 @@
 OC.L10N.register(
     "dav",
     {
-    "Calendar" : "الجدول الزمني",
-    "Tasks" : "الأعمال",
+    "Calendar" : "التقويم",
+    "Tasks" : "المهام",
     "Personal" : "خاص",
     "{actor} created calendar {calendar}" : "{actor} قام بإنشاء تقويم {calendar}",
     "You created calendar {calendar}" : "قمت بإنشاء التقويم {calendar}",
@@ -72,10 +72,20 @@ OC.L10N.register(
     "Description: %s" : "الوصف: %s",
     "Where: %s" : "المكان: %s",
     "%1$s via %2$s" : "%1$s عبر %2$s",
-    "In a %1$s on %2$s for the entire day" : "عند %1$s في %2$s كامل اليوم",
-    "In a %1$s on %2$s between %3$s - %4$s" : "عند %1$s في %2$s بين %3$s - %4$s",
-    "In %1$s %2$s on %3$s for the entire day" : "عند %1$s %2$s في %3$s كامل اليوم",
-    "In %1$s %2$s on %3$s between %4$s - %5$s" : "عند %1$s %2$s في %3$s بين %4$s - %5$s",
+    "In the past on %1$s for the entire day" : "في الماضي في %1$s لكامل اليوم",
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["في %n دقيقة في %1$s لكامل اليوم","في  %1$s for the entire day","في %n دقيقة في %1$s لكامل اليوم","في %n دقائق في %1$s لكامل اليوم","في %n دقيقة في %1$s لكامل اليوم","في %n دقيقة في %1$s لكامل اليوم"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["في %n ساعة في %1$s لكامل اليوم","في ساعة واحدة في %1$s لكامل اليوم","في %n ساعة في %1$s لكامل اليوم","في %n ساعات في %1$s لكامل اليوم","في %n ساعة في %1$s لكامل اليوم","في %n ساعة في %1$s لكل اليوم"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["في%n يوم في %1$s لكامل اليوم","في يوم واحد في %1$s لكامل اليوم","في %n يوم في %1$s لكامل اليوم","في %n أيام في %1$s لكامل ايوم","في %n يوم في %1$s لكامل اليوم","في %n يوم في %1$s لكامل اليوم"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["في %n أسبوع في %1$s طيلة اليوم","في أسبوع في %1$s طيلة اليوم","في %n أسبوع في %1$s طيلة اليوم","في %n أسابيع في %1$s طيلة اليوم","في %n أسبوع في %1$s طيلة اليوم","في %n أسبوع في %1$s طيلة اليوم"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["في %n شهر في %1$s طيلة اليوم","في شهر في %1$s طيلة اليوم","في %n شهر في %1$s طيلة اليوم","في %n أشهر في %1$s طيلة اليوم","في %n شهر في %1$s طيلة اليوم","في %n شهر في %1$s طيلة اليوم"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["في %n سنة في %1$s طيلة اليوم","في سنة في %1$s طيلة اليوم","في %n سنة في %1$s طيلة اليوم","في %n سنوات في %1$s طيلة اليوم","في %n سنة في %1$s طيلة اليوم","في %n سنة في %1$s طيلة اليوم"],
+    "In the past on %1$s between %2$s - %3$s" : "في الماضي في %1$s بين %2$s - %3$s",
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["في %n دقيقة في %1$s بين %2$s - %3$s","في دقيقة فقي %1$s بين %2$s - %3$s","في %n دقيقة فقي %1$s بين %2$s - %3$s","في %n دقائق في %1$s بين %2$s - %3$s","في %n دقيقة في %1$s بين %2$s - %3$s","في %n دقيقة في %1$s بين %2$s - %3$s"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["في %n ساعة في %1$s بين %2$s - %3$s","في ساعة واحدة %1$s بين %2$s - %3$s","في %n ساعة في %1$s بين %2$s - %3$s","في %n ساعات في %1$s بين %2$s - %3$s","في %n ساعة في %1$s بين %2$s - %3$s","في %n ساعة في %1$s بين %2$s - %3$s"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["في%n يوم في %1$s بين %2$s - %3$s","في يوم واحد في %1$s بين %2$s - %3$s","في %n يوم %1$s بين %2$s - %3$s","في %n أيام في %1$s بين %2$s - %3$s","في %n يوم في %1$s بين %2$s - %3$s","في %n يوم في %1$s بين %2$s - %3$s"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["في %n أسبوع في %1$s بين %2$s - %3$s","في أسبوع واحد في %1$s بين %2$s - %3$s","في %n أسبوع في %1$s بين %2$s - %3$s","في %n أسابيع في %1$s في %2$s - %3$s","في %n أسبوع في %1$s بين %2$s - %3$s","في %n أسبوع في %1$s بين %2$s - %3$s"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["في %n شهر في %1$s بين %2$s - %3$s","في شهر واحد في %1$s بين %2$s - %3$s","في %n شهر في %1$s بين %2$s - %3$s","في %n شهور في %1$s بين %2$s - %3$s","في %n شهر في %1$s بين %2$s - %3$s","In %n months on %1$s between %2$s - %3$s"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["في %n سنة في %1$s بين %2$s - %3$s","في سنة واحدة في %1$s بين %2$s - %3$s","في %n سنة في %1$s بين %2$s - %3$s","في %n سنوات في %1$s بين %2$s - %3$s","في %n سنة في %1$s بين %2$s - %3$s","في %n سنة في %1$s بين %2$s - %3$s"],
     "Could not generate when statement" : "يتعذّر تكوين عبارة \"متى\"",
     "Every Day for the entire day" : "كل يوم لكامل اليوم",
     "Every Day for the entire day until %1$s" : "كل يوم كامل اليوم حتى %1$s",
@@ -112,12 +122,27 @@ OC.L10N.register(
     "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "كل %1$d سنة في %2$s أيام %3$s بين %4$s - %5$s حتى %6$s",
     "On specific dates for the entire day until %1$s" : "في تورايخ محددة كامل اليوم حتى%1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "في تواريخ محددة بين %1$s - %2$s حتى %3$s",
-    "In a %1$s on %2$s" : "عند %1$s في %2$s",
-    "In a %1$s on %2$s then on %3$s" : "عند %1$s في %2$s ثم في%3$s",
-    "In a %1$s on %2$s then on %3$s and %4$s" : "عند %1$s في %2$s ثم في %3$s و %4$s",
-    "In %1$s %2$s on %3$s" : "عند %1$s %2$s في %3$s",
-    "In %1$s %2$s on %3$s then on %4$s" : "عند %1$s %2$s في %3$s ثم في %4$s",
-    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "عند %1$s %2$s في %3$s ثم في %4$s و%5$s",
+    "In the past on %1$s" : "في الماضي في %1$s",
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["في %n دقيقة في %1$s","في دقيقة واحدة في %1$s","في %n دقيقة في %1$s","في %n دقائق في %1$s","في %n دقيقة في %1$s","في %n دقيقة في %1$s"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["في %n ساعة في %1$s","في ساعة واحدة في%1$s","في %n ساعة في %1$s","في %n ساعات في %1$s","في %n ساعة في %1$s","في %n ساعة في %1$s"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["في %n يوم في %1$s","في يوم واحد في%1$s","في %n يوم في %1$s","في %n أيام في %1$s","في %n يوم في%1$s","في %n يوم في %1$s"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["في %n أسبوع في %1$s","في أسبوع واحد في %1$s","في %n أسبوع في %1$s","في %n أسابيع في %1$s","في %n أسبوع في %1$s","في %n أسبوع في %1$s"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["في %n شهر في %1$s","في شهر واحد في %1$s","في %n شهر في %1$s","في %n أشهر في %1$s","في %n شهر في %1$s","في %n شهر في %1$s"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["في %n سنة في %1$s","في سنة واحدة في %1$s","في %n سنة في %1$s","في %n سنوات في %1$s","في %n سنة في %1$s","في %n سنة في %1$s"],
+    "In the past on %1$s then on %2$s" : "في الماضي في %1$s ثم في %2$s",
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["في %n دقيقة في %1$s ثم في %2$s","في دقيقة واحدة في %1$s ثم في %2$s","في %n دقيقة في %1$s ثم في %2$s","فيب %n دقائق في %1$s ثم في %2$s","في %n دقيقة في %1$s ثم في %2$s","في %n دقيقة في %1$s ثم في %2$s"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["في %n ساعة في %1$s ثم في %2$s","في ساعة واحدة في %1$s ثم في %2$s","في %n ساعة في %1$s ثم في %2$s","في %n ساعات في %1$s ثم في %2$s","في %n ساعة في %1$s ثم في %2$s","في %n ساعة في %1$s ثم في %2$s"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["في %n يوم في %1$s ثم في %2$s","في يوم واحد في %1$s ثم في %2$s","في %n يوم في %1$s ثم في %2$s","في %n أيام في %1$s ثم في %2$s","في %n يوم في %1$s ثم في %2$s","في %n يوم في %1$s ثم في %2$s"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["في %n أسبوع في %1$s ثم في %2$s","في أسبوع واحد في %1$s ثم في %2$s","في %n أسبوع في %1$s ثم في %2$s","في %n أسابيع في %1$s ثم في %2$s","في %n أسبوع في %1$s ثم في %2$s","في %n أسبوع في %1$s ثم في %2$s"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["في %n شهر في %1$s ثم في %2$s","في شهر واحد في %1$s ثم في %2$s","في %n شهر في %1$s ثم في %2$s","في %n شهور في %1$s ثم في %2$s","في %n شهر في %1$sثم في %2$s","في %n شهر في %1$s ثم في %2$s"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["في %n سنة في %1$s ثم في %2$s","في سنة واحدة في %1$s ثم في %2$s","في %n سنة في %1$s ثم في %2$s","في %n سنوات في %1$s ثم في %2$s","في %n سنة في %1$s ثم في %2$s","في %n سنة في %1$s ثم في %2$s"],
+    "In the past on %1$s then on %2$s and %3$s" : "في الماضي في %1$s ثم في %2$s و %3$s",
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["في %n دقيقة في %1$s ثم في %2$s و %3$s","في دقيقة واحدة في %1$s ثم في %2$s و %3$s","في %n دقيقة في %1$s ثم في %2$s و %3$s","في %n دقائق في %1$s ثم في %2$s و %3$s","في %n دقيقة في %1$s ثم في %2$s و %3$s","في %n دقيقة في %1$s ثم في %2$s و %3$s"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["في %n ساعة في %1$s ثم في %2$s و %3$s","في ساعة واحدة في %1$s ثم في %2$s و %3$s","في %n ساعة في %1$s ثم في %2$s و %3$s","في %n ساعات في %1$s ثم في %2$s و %3$s","في %n ساعة في %1$s ثم في %2$s و %3$s","في %n ساعة في %1$s ثم في %2$s و %3$s"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["في %n يوم في %1$s ثم في %2$s و %3$s","في يوم واحد في %1$s ثم ف %2$s و %3$s","في %n يوم في %1$s ثم في %2$s و %3$s","في %n أيام في %1$s ثم في %2$s و %3$s","في %n يوم في %1$s ثم في %2$s و %3$s","في %n يوم في %1$s ثم في %2$s و %3$s"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["في %n أسبوع في %1$s ثم في %2$s و %3$s","في أسبوع واحد في %1$s ثم في %2$s و %3$s","في %n أسبوع في %1$s ثم في %2$s و %3$s","في %n أسابيع في %1$s ثم في %2$s و %3$s","في %n أسبوع في %1$s ثم في %2$s و %3$s","في %n أسبوع في %1$s ثم في %2$s و %3$s"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["في %n شهر في %1$s ثم في %2$s و %3$s","في شهر واحد في %1$s ثم في %2$s و %3$s","في %n شهر في %1$s ثم في %2$s و %3$s","في %n شهور في %1$s ثم في %2$s و %3$s","في %n شهر في %1$s ثم في %2$s و %3$s","في %n شهر في %1$s ثم في %2$s و %3$s"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["في%n سنة في %1$s ثم في %2$s و %3$s","في سنة واحدة في %1$s ثم في %2$s و %3$s","في %n سنة في %1$s ثم في %2$s و %3$s","في %n سنوات في %1$s ثم في %2$s و %3$s","في %n سنة في %1$s ثم في %2$s و %3$s","في %n سنة في %1$s ثم في %2$s و %3$s"],
     "Could not generate next recurrence statement" : "يتعذّر توليد عبارة التكرار التالي",
     "Cancelled: %1$s" : "مُلغىً: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" تمّ إلغاؤه",
@@ -164,12 +189,12 @@ OC.L10N.register(
     "Second" : "ثاني",
     "Third" : "ثالث",
     "Fourth" : "رابع",
-    "Fifty" : "خامس",
+    "Fifth" : "خامس",
     "Last" : "آخِر",
     "Second Last" : "ما قبل الأخير",
     "Third Last" : "الثالث من الآخِر",
     "Fourth Last" : "الرابع من الآخِر",
-    "Fifty Last" : "الخامس من الآخِر",
+    "Fifth Last" : "خامس من الأخير",
     "Contacts" : "جهات الاتصال",
     "{actor} created address book {addressbook}" : "{actor} أنشأ دفتر العناوين {addressbook}",
     "You created address book {addressbook}" : "أنت أنشأت دفتر العناوين {addressbook}",
@@ -207,7 +232,8 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "تعذّرت إعادة تسمية ملف جزئي إلى ملف نهائي. تمّ الإلغاء من قِبَل الخطّاف hook.",
     "Could not rename part file to final file" : "تعذّرت إعادة تسمية ملف جزئي إلى ملف نهائي",
     "Failed to check file size: %1$s" : "فشل في تحديد حجم الملف: %1$s",
-    "Could not open file" : "تعذّر فتح الملف",
+    "Could not open file: %1$s, file does seem to exist" : "يتعذّر فتح الملف: %1$s, يبدو أن الملف غير موجود",
+    "Could not open file: %1$s, file doesn't seem to exist" : "يتعذّر فتح الملف: %1$s, يبدو أن الملف غير موجود",
     "Encryption not ready: %1$s" : "التشفير غير جاهز: %1$s",
     "Failed to open file: %1$s" : "تعذّر فتح الملف: %1$s",
     "Failed to unlink: %1$s" : "تعذّر فك الارتباط: %1$s",
@@ -224,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "تمّ الانتهاء منه في %s",
     "Due on %s by %s" : "مطلوبٌ في %s من قِبَل%s",
     "Due on %s" : "مطلوبٌ في %s",
+    "System Address Book" : "دفتر عناوين النظام",
+    "The system address book contains contact information for all users in your instance." : "دفتر عناوين النظام يحتوي على معلومات الاتصال لجميع المستخدِمين على خادومك. ",
+    "Enable System Address Book" : "تمكين دفتر عناوين النظام",
     "DAV system address book" : "دفتر عناوين نظام DAV",
     "No outstanding DAV system address book sync." : "لا توجد أي مزامنات معلقة لدفتر عناوني نظام DAV.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "لم يتم تشغيل مزامنة دفتر عناوين نظام DAV حتى الآن بسبب أن الخادم الخاص بك يحتوي على أكثر من 1000 مستخدم أو بسبب حدوث خطأ. يرجى تشغيل المزامنة يدويًا عن طريق الأمر السطري:\n\"occ dav:sync-system-addressbook\"",
@@ -235,6 +264,10 @@ OC.L10N.register(
     "Calendars including events, details and attendees" : "تحوي التقاويم الأحداث، و تفاصيلها، و الحُضُور",
     "Contacts and groups" : "جهات الاتصال والمجموعات",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "تمّ حفظ الغياب",
+    "Failed to save your absence settings" : "تعذّر حفظ إعداداتك للغياب",
+    "Absence cleared" : "تمّ محو الغياب",
+    "Failed to clear your absence settings" : "تعذّر محو إعداداتك للغياب",
     "First day" : "أول يوم",
     "Last day (inclusive)" : "آخر يوم (متضمن)",
     "Out of office replacement (optional)" : "البديل لمن هو خارج المكتب (إختياري)",
@@ -245,26 +278,24 @@ OC.L10N.register(
     "Long absence Message" : "رسالة الغياب الطويل",
     "Save" : "حفظ",
     "Disable absence" : "تعطيل الغياب",
-    "Absence saved" : "تمّ حفظ الغياب",
-    "Failed to save your absence settings" : "تعذّر حفظ إعداداتك للغياب",
-    "Absence cleared" : "تمّ محو الغياب",
-    "Failed to clear your absence settings" : "تعذّر محو إعداداتك للغياب",
+    "Failed to load availability" : "فشل في تحميل أوقات التواجد",
+    "Saved availability" : "تمّ حفظ أوقات التواجد",
+    "Failed to save availability" : "تعذّر حفظ أوقات التواجد",
     "Time zone:" : "منطقة زمنية:",
     "to" : "إلى",
-    "Delete slot" : "حذف فُرَضَةٍ slot زمنيّةٍ",
+    "Delete slot" : "حذف الخانة الزمنية",
     "No working hours set" : "لم يتم تحديد ساعات العمل",
-    "Add slot" : "إضافة فترة زمنية",
+    "Add slot" : "إضافة خانة زمنية",
     "Weekdays" : "أيام الأسبوع",
     "Pick a start time for {dayName}" : "إختَر وقت البدء ليوم {dayName}",
     "Pick a end time for {dayName}" : "إختَر وقت الانتهاء ليوم {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "قم بتعيين حالة المستخدم تلقائيًا على \"عدم الإزعاج\" خارج نطاق أوقات التواجد لكتم جميع الإشعارات",
-    "Failed to load availability" : "فشل في تحميل أوقات التواجد",
-    "Saved availability" : "تمّ حفظ أوقات التواجد",
-    "Failed to save availability" : "تعذّر حفظ أوقات التواجد",
     "Availability" : "أوقات التواجد ",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "إذا قمت بضبط ساعات عملك، سيرى الآخرون متى تكون خارج المكتب عندما يقومون بحجز اجتماع معك.",
     "Absence" : "غياب",
     "Configure your next absence period." : "تهيئة فترة غيابك القادمة.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "قم أيضاً بتنصيب {calendarappstoreopen} تطبيق التقويم {linkclose}, أو  {calendardocopen} أوصل جهازك و موبايلك للمُزامنة ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "رجاءُ، تأكّد من الإعداد الصحيح لـ {emailopen} خادم البريد الالكتروني {linkclose}.",
     "Calendar server" : "خادم التقويم",
     "Send invitations to attendees" : "إرسال دعوات للمطلوب حضورهم",
     "Automatically generate a birthday calendar" : "تجاهل تقويم أعياد الميلاد تلقائيّاً",
@@ -275,17 +306,27 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "أرسل إشعارات للتذكير إلى المشتركين بالتقويم كذلك",
     "Reminders are always sent to organizers and attendees." : "إشعارات التذكير يتم إرسالها دائماً إلى مُنظّم أو مُنظّمي الحدث و المستهدفين بحضوره.",
     "Enable notifications for events via push" : "تمكين الإشعارات حول الأحداث عن طريق أسلوب دفع الإشعارات Push",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "قم أيضاً بتنصيب {calendarappstoreopen} تطبيق التقويم {linkclose}, أو  {calendardocopen} أوصل جهازك و موبايلك للمُزامنة ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "رجاءُ، تأكّد من الإعداد الصحيح لـ {emailopen} خادم البريد الالكتروني {linkclose}.",
+    "Cancel" : "إلغاء",
+    "Import" : "إستيراد",
+    "Error while saving settings" : "خطأ أثناء حفظ الإعدادات",
+    "Contact reset successfully" : "تمّت إعادة تعيين جهة الاتصال بنجاحٍ",
+    "Error while resetting contact" : "خطأ أثناء إعادة تعيين جهة الاتصال",
+    "Contact imported successfully" : "تمّ استيراد جهة الاتصال بنجاحٍ",
+    "Error while importing contact" : "خطأ أثناء استيراد جهة الاتصال",
+    "Example Content" : "نموذج للمحتوى",
+    "Set example content to be created on new user first login." : "عيِّن نموذجاً للمحتوى ليتم إنشاؤه عند تسجيل المستخدِم دخوله لأول مرةٍ.",
+    "Import contact" : "استيراد جهة اتصال",
+    "Reset to default contact" : "إعادة التعيين لجهة اتصال تلقائية ",
+    "Import contacts" : "استيراد جهات اتصال",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "استيراد ملف .cvf جديد سوف يؤدي إلى حذف جهات الاتصال التلقائية الحالية واستبدالها بالجديدة. هل ترغب في الاستمرار؟",
     "There was an error updating your attendance status." : "حدث خطأ في تحديث حالة حضورك.",
     "Please contact the organizer directly." : "يرجى الاتصال بالمنظم مباشرةً",
     "Are you accepting the invitation?" : "هل تقبل الدعوة؟",
     "Tentative" : "مبدئي",
     "Your attendance was updated successfully." : "حضورك تم تحديثه بنجاحٍ",
-    "To-dos" : "قائمة المهام",
     "Time:" : "الوقت:",
+    "Could not open file" : "تعذّر فتح الملف",
     "Invalid chunk name" : "اسم كتلة chunk غير صحيح",
-    "Could not rename part file assembled from chunks" : "تعذّرت إعادة تسمية ملف جزئي مُجمّعٍ من كُتلٍ chunks",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "إذا قمت بتهيئة ساعات العمل الخاصة بك، فسيظهر للمستخدمين الآخرين عندما يحجزون معك موعداً إذا ما كنت في المكتب أو خارجه."
+    "Could not rename part file assembled from chunks" : "تعذّرت إعادة تسمية ملف جزئي مُجمّعٍ من كُتلٍ chunks"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
