@@ -72,6 +72,78 @@ OC.L10N.register(
     "Description: %s" : "Açıklama: %s",
     "Where: %s" : "Şurada: %s",
     "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
+    "In the past on %1$s for the entire day" : "Tüm gün boyunca %1$s zamanında geçmişte",
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir dakika içinde","Tüm gün boyunca %1$s zamanında %n dakika içinde"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir saat içinde","Tüm gün boyunca %1$s zamanında %n saat içinde"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir gün içinde","Tüm gün boyunca %1$s zamanında %n gün içinde"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir hafta içinde","Tüm gün boyunca %1$s zamanında %n hafta içinde"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir ay içinde","Tüm gün boyunca %1$s zamanında %n ay içinde"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Tüm gün boyunca %1$s zamanında bir yıl içinde","Tüm gün boyunca %1$s zamanında %n yıl içinde"],
+    "In the past on %1$s between %2$s - %3$s" : "Geçmişte %1$s zamanında %2$s ile %3$s arasında",
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Bir dakika içinde %1$s zamanında %2$s ile %3$s arasında","%n dakika içinde %1$s zamanında %2$s ile %3$s arasında"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Bir saat içinde %1$s zamanında %2$s ile %3$s arasında","%n saat içinde %1$s zamanında %2$s ile %3$s arasında"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Bir gün içinde %1$s zamanında %2$s ile %3$s arasında","%n gün içinde %1$s zamanında %2$s ile %3$s arasında"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["Bir hafta içinde %1$s zamanında %2$s ile %3$s arasında","%n hafta içinde %1$s zamanında %2$s ile %3$s arasında"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Bir ay içinde %1$s zamanında %2$s ile %3$s arasında","%n ay içinde %1$s zamanında %2$s ile %3$s arasında"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["Bir yıl içinde %1$s zamanında %2$s ile %3$s arasında","%n yıl içinde %1$s zamanında %2$s ile %3$s arasında"],
+    "Could not generate when statement" : "Zaman ifadesi oluşturulamadı",
+    "Every Day for the entire day" : "Her gün tüm gün boyunca",
+    "Every Day for the entire day until %1$s" : "%1$s zamanına kadar her gün tüm gün boyunca",
+    "Every Day between %1$s - %2$s" : "Her gün %1$s ile %2$s arasında",
+    "Every Day between %1$s - %2$s until %3$s" : "%3$s zamanına kadar %1$s ile %2$s arasında her gün",
+    "Every %1$d Days for the entire day" : "Her %1$d günde tüm gün boyunca",
+    "Every %1$d Days for the entire day until %2$s" : "%2$s zamanına kadar her %1$d günde tüm gün boyunca",
+    "Every %1$d Days between %2$s - %3$s" : "Her %1$d günde %2$s ile %3$s arasında",
+    "Every %1$d Days between %2$s - %3$s until %4$s" : "%4$s zamanına kadar her %1$d günde %2$s ile %3$s",
+    "Could not generate event recurrence statement" : "Etkinlik yinelenme ifadesi oluşturulamadı",
+    "Every Week on %1$s for the entire day" : "Her hafta %1$s zamanında tüm gün boyunca",
+    "Every Week on %1$s for the entire day until %2$s" : "Her hafta %1$s zamanında tüm gün boyunca %2$s zamanına kadar",
+    "Every Week on %1$s between %2$s - %3$s" : "Her hafta %1$s zamanında %2$s ile %3$s arasında",
+    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Her hafta %1$s zamanında %2$s ile %3$s arasında %4$s zamanına kadar",
+    "Every %1$d Weeks on %2$s for the entire day" : "Her %1$d haftada bir %2$s zamanında tüm gün boyunca",
+    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Her %1$d haftada bir %2$s zamanında tüm gün boyunca %3$s zamanına kadar",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Her %1$d haftada bir %2$s zamanında tüm gün boyunca %3$s ile %4$s arasında",
+    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Her %1$d haftada bir %2$s zamanında %3$s ile %4$s arasında %5$s zamanına kadar",
+    "Every Month on the %1$s for the entire day" : "Her ay %1$s zamanında tüm gün boyunca",
+    "Every Month on the %1$s for the entire day until %2$s" : "Her ay %1$s zamanında tüm gün boyunca %2$s zamanına kadar",
+    "Every Month on the %1$s between %2$s - %3$s" : "Her ay %1$s zamanında %2$s ile %3$s arasında",
+    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Her ay %1$s zamanında %2$s ile %3$s arasında %4$s zamanına kadar",
+    "Every %1$d Months on the %2$s for the entire day" : "Her %1$d ayda bir %2$s zamanında tüm gün boyunca",
+    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Her %1$d ayda bir %2$s zamanında tüm gün boyunca %3$s zamanına kadar",
+    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Her %1$d ayda bir %2$s zamanında tüm gün boyunca %3$s ile %4$s arasında",
+    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Her %1$d ayda bir %2$s zamanında %3$s ile %4$s arasında %5$s zamanına kadar",
+    "Every Year in %1$s on the %2$s for the entire day" : "Her yıl %1$s içinde %2$s zamanında tüm gün boyunca",
+    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Her yıl %1$s içinde %2$s zamanında tüm gün boyunca %3$s zamanına kadar",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Her yıl %1$s içinde %2$s zamanında tüm gün boyunca %3$s ile %4$s arasında",
+    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Her yıl %1$s içinde %2$s zamanında %3$s ile %4$s arasında %5$s zamanına kadar",
+    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Her %1$d yılda bir %2$s içinde %3$s zamanında tüm gün boyunca",
+    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Her %1$d yılda bir %2$s içinde %3$s zamanında tüm gün boyunca %4$s zamanına kadar",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Her %1$d yılda bir %2$s içinde %3$s zamanında tüm gün boyunca %4$s ile %5$s arasında",
+    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Her %1$d yılda bir %2$s içinde %3$s zamanında %4$s ile %5$s arasında %6$s zamanına kadar",
+    "On specific dates for the entire day until %1$s" : "Belirli tarihlerde tüm gün boyunca %1$s zamanına kadar",
+    "On specific dates between %1$s - %2$s until %3$s" : "Belirli tarihlerde %1$s ile %2$s arasında %3$s zamanına kadar",
+    "In the past on %1$s" : "%1$s zamanında geçmişte",
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["%1$s zamanında bir dakika içinde","%1$s zamanında %n dakika içinde"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["%1$s zamanında bir saat içinde","%1$s zamanında %n saat içinde"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["%1$s zamanında bir gün içinde","%1$s zamanında %n gün içinde"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["%1$s zamanında bir hafta içinde","%1$s zamanında %n hafta içinde"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["%1$s zamanında bir ay içinde","%1$s zamanında %n ay içinde"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["%1$s zamanında bir yıl içinde","%1$s zamanında %n yıl içinde"],
+    "In the past on %1$s then on %2$s" : "Geçmişte %1$s zamanında ardından %2$s zamanında",
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Bir dakika içinde %1$s zamanında ardından %2$s zamanında","%n dakika içinde %1$s zamanında ardından %2$s zamanında"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Bir saat içinde %1$s zamanında ardından %2$s zamanında","%n saat içinde %1$s zamanında ardından %2$s zamanında"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Bir gün içinde %1$s zamanında ardından %2$s zamanında","%n gün içinde %1$s zamanında ardından %2$s zamanında"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["Bir hafta içinde %1$s zamanında ardından %2$s zamanında","%n hafta içinde %1$s zamanında ardından %2$s zamanında"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Bir ay içinde %1$s zamanında ardından %2$s zamanında","%n ay içinde %1$s zamanında ardından %2$s zamanında"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["Bir yıl içinde %1$s zamanında ardından %2$s zamanında","%n yıl içinde %1$s zamanında ardından %2$s zamanında"],
+    "In the past on %1$s then on %2$s and %3$s" : "Geçmişte %1$s zamanında ardından %2$s ve %3$s zamanında",
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Bir dakika içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n dakika içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Bir saat içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n saat içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Bir gün içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n gün içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["Bir hafta içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n hafta içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Bir ay içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n ay içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Bir yıl içinde %1$s zamanında ardından %2$s ve %3$s zamanında","%n yıl içinde %1$s zamanında ardından %2$s ve %3$s zamanında"],
+    "Could not generate next recurrence statement" : "Sonraki yinelenme ifadesi oluşturulamadı",
     "Cancelled: %1$s" : "İptal edildi: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" iptal edildi",
     "Re: %1$s" : "Ynt: %1$s",
@@ -86,13 +158,43 @@ OC.L10N.register(
     "Organizer:" : "Düzenleyen:",
     "Attendees:" : "Katılımcılar:",
     "Title:" : "Başlık:",
-    "Time:" : "Zaman:",
+    "When:" : "Zaman:",
     "Location:" : "Konum:",
     "Link:" : "Bağlantı:",
+    "Occurring:" : "Başlangıç:",
     "Accept" : "Kabul et",
     "Decline" : "Reddet",
     "More options …" : "Diğer seçenekler …",
     "More options at %s" : "%s üzerindeki diğer seçenekler",
+    "Monday" : "Pazartesi",
+    "Tuesday" : "Salı",
+    "Wednesday" : "Çarşamba",
+    "Thursday" : "Perşembe",
+    "Friday" : "Cuma",
+    "Saturday" : "Cumartesi",
+    "Sunday" : "Pazar",
+    "January" : "Ocak",
+    "February" : "Şubat",
+    "March" : "Mart",
+    "April" : "Nisan",
+    "May" : "Mayıs",
+    "June" : "Haziran",
+    "July" : "Temmuz",
+    "August" : "Ağustos",
+    "September" : "Eylül",
+    "October" : "Ekim",
+    "November" : "Kasım",
+    "December" : "Aralık",
+    "First" : "İlk",
+    "Second" : "İkinci",
+    "Third" : "Üçüncü",
+    "Fourth" : "Dördüncü",
+    "Fifth" : "Beşinci",
+    "Last" : "Son",
+    "Second Last" : "İkinci son",
+    "Third Last" : "Üçüncü son",
+    "Fourth Last" : "Dördüncü son",
+    "Fifth Last" : "Beşinci son",
     "Contacts" : "Kişiler",
     "{actor} created address book {addressbook}" : "{actor}, {addressbook} adres defterini ekledi",
     "You created address book {addressbook}" : "{addressbook} adres defterini eklediniz",
@@ -121,6 +223,7 @@ OC.L10N.register(
     "Accounts" : "Hesaplar",
     "System address book which holds all accounts" : "Tüm hesapların bulunduğu sistem adres defteri",
     "File is not updatable: %1$s" : "Dosya güncellenebilir değil: %1$s",
+    "Failed to get storage for file" : "Dosyanın depolaması alınamadı",
     "Could not write to final file, canceled by hook" : "Sonuç dosyasına yazılamadı, bağlantı tarafından iptal edildi",
     "Could not write file contents" : "Dosya içerikleri yazılamadı",
     "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
@@ -129,14 +232,14 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "Parça dosyası sonuç dosyası olarak yeniden adlandırılamadı, bağlantı tarafından iptal edildi",
     "Could not rename part file to final file" : "Parça dosyası sonuç dosyası olarak yeniden adlandırılamadı",
     "Failed to check file size: %1$s" : "Dosya boyutu denetlenemedi: %1$s",
-    "Could not open file" : "Dosya açılamadı",
+    "Could not open file: %1$s, file does seem to exist" : "Dosya açılamadı: %1$s, dosya var gibi görünüyor",
+    "Could not open file: %1$s, file doesn't seem to exist" : "Dosya açılamadı: %1$s, dosya var gibi görünmüyor",
     "Encryption not ready: %1$s" : "Şifreleme hazır değil: %1$s",
     "Failed to open file: %1$s" : "Dosya açılamadı: %1$s",
     "Failed to unlink: %1$s" : "Bağlantı kaldırılamadı: %1$s",
-    "Invalid chunk name" : "Parça adı geçersiz",
-    "Could not rename part file assembled from chunks" : "Parçalardan oluşturulan parça dosyası yeniden adlandırılamadı ",
     "Failed to write file contents: %1$s" : "Dosya içerikleri yazılamadı: %1$s",
     "File not found: %1$s" : "Dosya bulunamadı: %1$s",
+    "Invalid target path" : "Hedef yol geçersiz",
     "System is in maintenance mode." : "Sistem bakım kipinde.",
     "Upgrade needed" : "Yükseltme gerekiyor",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS/macOS üzerinde CalDAV ve CardDAV kullanabilmek için %s HTTPS kullanacak şekilde yapılandırılmalıdır.",
@@ -147,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "%s tarihinde tamamlandı",
     "Due on %s by %s" : "%s tarihine kadar %s tarafından",
     "Due on %s" : "%s tarihine kadar",
+    "System Address Book" : "Sistem adres defteri",
+    "The system address book contains contact information for all users in your instance." : "Sistem adres defterinde, kopyanızdaki tüm kullanıcıların iletişim bilgileri bulunur.",
+    "Enable System Address Book" : "Sistem adres defteri kullanılsın",
     "DAV system address book" : "DAV sistem adres defteri",
     "No outstanding DAV system address book sync." : "Bekleyen bir DAV sistemi adres defteri eşitlemesi yok.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Kopyanızda 1000 üzerinde kullanıcı olduğundan ya da bir sorun çıktığından DAV sistemi adres defteri eşitlemesi henüz yapılmamış. Lütfen \"occ dav:sync-system-addressbook\" komutunu yürüterek el ile eşitleyin.",
@@ -158,57 +264,69 @@ OC.L10N.register(
     "Calendars including events, details and attendees" : "Etkinlikler, bilgiler ve katılımcılar ile takvimler",
     "Contacts and groups" : "Kişiler ve gruplar",
     "WebDAV" : "WebDAV",
+    "Absence saved" : "Bulunmama kaydedildi",
+    "Failed to save your absence settings" : "Bulunmama ayarlarınız kaydedilemedi",
+    "Absence cleared" : "Bulunmama temizlendi",
+    "Failed to clear your absence settings" : "Bulunmama ayarlarınız temizlenemedi",
     "First day" : "İlk gün",
     "Last day (inclusive)" : "Son gün (dahil)",
-    "Short absence status" : "Kısa işe gelmeme durumu",
-    "Long absence Message" : "Uzun işe gelmeme iletisi",
+    "Out of office replacement (optional)" : "Ofis dışındayken yerine bakacak kişi (isteğe bağlı)",
+    "Name of the replacement" : "Yerine bakacak kişi adı",
+    "No results." : "Herhangi bir sonuç bulunamadı.",
+    "Start typing." : "Yazmaya başlayın.",
+    "Short absence status" : "Kısa bulunmama durumu",
+    "Long absence Message" : "Uzun bulunmama iletisi",
     "Save" : "Kaydet",
-    "Disable absence" : "İşe gelmemeyi kapat",
-    "Absence saved" : "İşe gelmeme kaydedildi",
-    "Failed to save your absence settings" : "İşe gelmeme ayarlarınız kaydedilemedi",
-    "Absence cleared" : "İşe gelmeme temizlendi",
-    "Failed to clear your absence settings" : "İşe gelmeme ayarlarınız temizlenemedi",
+    "Disable absence" : "Bulunmamayı kapat",
+    "Failed to load availability" : "Uygunluk yüklenemedi",
+    "Saved availability" : "Uygunluk kaydedildi",
+    "Failed to save availability" : "Uygunluk kaydedilemedi",
     "Time zone:" : "Saat dilimi:",
     "to" : "ile",
     "Delete slot" : "Aralığı sil",
     "No working hours set" : "Çalışma saatleri ayarlanmamış",
     "Add slot" : "Aralık ekle",
     "Weekdays" : "Hafta içi günleri",
-    "Monday" : "Pazartesi",
-    "Tuesday" : "Salı",
-    "Wednesday" : "Çarşamba",
-    "Thursday" : "Perşembe",
-    "Friday" : "Cuma",
-    "Saturday" : "Cumartesi",
-    "Sunday" : "Pazar",
     "Pick a start time for {dayName}" : "{dayName} için başlangıç zamanını seçin",
     "Pick a end time for {dayName}" : "{dayName} için bitiş zamanını seçin",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Tüm bildirimleri sessize almak için, uygunluk durumu dışında kullanıcı durumu otomatik olarak \"Rahatsız etmeyin\" olarak ayarlanır.",
-    "Failed to load availability" : "Uygunluk yüklenemedi",
-    "Saved availability" : "Uygunluk kaydedildi",
-    "Failed to save availability" : "Uygunluk kaydedilemedi",
     "Availability" : "Uygunluk",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Çalışma saatlerinizi ayarlarsanız, diğer kişiler bir toplantı ayarladıklarında ofis dışında olduğunuzu görürler.",
-    "Absence" : "İşe gelmeme",
-    "Configure your next absence period." : "Sonraki işe gelmeme aralığınızı yapılandırın.",
+    "Absence" : "Bulunmama",
+    "Configure your next absence period." : "Sonraki bulunmama aralığınızı yapılandırın.",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Ayrıca {calendarappstoreopen}Takvim Uygulamasını{linkclose} kurun ya da {calendardocopen}bilgisayarınızı ya da taşınabilir aygıtınızı eşitlemek üzere bağlayın  ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Lütfen {emailopen}e-posta sunucusunu{linkclose} doğru ayarladığınızdan emin olun.",
     "Calendar server" : "Takvim sunucusu",
     "Send invitations to attendees" : "Katılımcılara davet gönder",
     "Automatically generate a birthday calendar" : "Doğum günü takvimi otomatik oluşturulsun",
-    "Birthday calendars will be generated by a background job." : "Bu seçenek etkinleştirildiğinde, doğum günü takvimi arka plan görevi olarak oluşturulur.",
-    "Hence they will not be available immediately after enabling but will show up after some time." : "Etkinleştirildikten hemen sonra görüntülenmez, bir süre sonra görüntülenir.",
+    "Birthday calendars will be generated by a background job." : "Bu seçenek kullanıma alındığında, doğum günü takvimi arka plan görevi olarak oluşturulur.",
+    "Hence they will not be available immediately after enabling but will show up after some time." : "Kullanıma alındıktan hemen sonra görüntülenmez, bir süre sonra görüntülenir.",
     "Send notifications for events" : "Etkinlik bildirimleri gönderilsin",
     "Notifications are sent via background jobs, so these must occur often enough." : "Bildirimler arka plan işlemleri tarafından gönderilir. Bu nedenle sıklık değeri uygun şekilde ayarlanmalıdır.",
     "Send reminder notifications to calendar sharees as well" : "Takvim paylaşımlarına da hatırlatma bildirimleri gönderilsin",
-    "Reminders are always sent to organizers and attendees." : "Bu seçenek etkinleştirildiğinde, hatırlatıcılar her zaman düzenleyici ve katılımcılara gönderilir.",
+    "Reminders are always sent to organizers and attendees." : "Bu seçenek kullanıma alındığında, hatırlatıcılar her zaman düzenleyici ve katılımcılara gönderilir.",
     "Enable notifications for events via push" : "Anında etkinlik bildirimlerini aç",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Ayrıca {calendarappstoreopen}Takvim Uygulamasını{linkclose} kurun ya da {calendardocopen}bilgisayarınızı ya da taşınabilir aygıtınızı eşitlemek üzere bağlayın  ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Lütfen {emailopen}e-posta sunucusunu{linkclose} doğru ayarladığınızdan emin olun.",
+    "Cancel" : "İptal",
+    "Import" : "İçe aktar",
+    "Error while saving settings" : "Ayarlar kaydedilirken sorun çıktı",
+    "Contact reset successfully" : "Kişi sıfırlandı",
+    "Error while resetting contact" : "Kişi sıfırlanırken sorun çıktı",
+    "Contact imported successfully" : "Kişi içe aktarıldı",
+    "Error while importing contact" : "Kişi içe aktarılırken sorun çıktı",
+    "Example Content" : "Örnek içerik",
+    "Set example content to be created on new user first login." : "Yeni kullanıcının ilk oturum açmasında oluşturulacak örnek içeriği ayarlayın.",
+    "Import contact" : "Kişiyi içe aktar",
+    "Reset to default contact" : "Varsayılan kişiye sıfırla",
+    "Import contacts" : "Kişileri içe aktar",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Yeni bir .vcf dosyasını içe aktarmak, var olan varsayılan kişiyi siler ve yenisiyle değiştirir. İlerlemek istiyor musunuz?",
     "There was an error updating your attendance status." : "Katılım durumunuz güncellenirken bir sorun çıktı.",
     "Please contact the organizer directly." : "Lütfen düzenleyici ile doğrudan görüşün.",
     "Are you accepting the invitation?" : "Daveti kabul ediyor musunuz?",
     "Tentative" : "Kesin değil",
     "Your attendance was updated successfully." : "Katılımınız güncellendi.",
-    "To-dos" : "Yapılacak işler",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Çalışma saatlerinizi ayarlarsanız, diğer kullanıcılar bir toplantı ayarladıklarında ofis dışında olduğunuzu görürler."
+    "Time:" : "Zaman:",
+    "Could not open file" : "Dosya açılamadı",
+    "Invalid chunk name" : "Parça adı geçersiz",
+    "Could not rename part file assembled from chunks" : "Parçalardan oluşturulan parça dosyası yeniden adlandırılamadı "
 },
 "nplurals=2; plural=(n > 1);");
