@@ -23,6 +23,7 @@ OC.L10N.register(
     "Sharing" : "Deling",
     "Federated file sharing" : "Sammenknyttet fildeling",
     "Provide federated file sharing across servers" : "Gi sammenknyttet fildeling på tvers av servere",
+    "Unable to update federated files sharing config" : "Kan ikke oppdatere sammenknyttet fildelingskonfigurasjon",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Juster hvordan personer kan dele mellom servere. Dette inkluderer også delinger mellom personer på denne serveren hvis de bruker sammenknyttet deling.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillat personer på denne serveren å sende delinger til andre servere (dette alternativet gir også WebDAV-tilgang til delte fellesressurser)",
     "Allow people on this server to receive shares from other servers" : "Tillat personer på denne serveren å motta delinger fra andre servere",
@@ -30,7 +31,11 @@ OC.L10N.register(
     "Allow people on this server to receive group shares from other servers" : "Tillat personer på denne serveren å motta gruppedelinger fra andre servere",
     "Search global and public address book for people" : "Søk i global og offentlig adressebok etter personer",
     "Allow people to publish their data to a global and public address book" : "Tillat brukere å offentliggjøre deres data til en verdensomspennende og offentlig adressebok",
-    "Unable to update federated files sharing config" : "Kan ikke oppdatere sammenknyttet fildelingskonfigurasjon",
+    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Del med meg gjennom min #Nextcloud ID for sammenknyttet sky, se {url}.",
+    "Share with me through my #Nextcloud Federated Cloud ID" : "Del med meg gjennom min #Nextcloud-ID for sammenknyttet sky",
+    "Cloud ID copied to the clipboard" : "Sky-ID kopiert til utklippstavlen",
+    "Copy to clipboard" : "Kopiert til utklippstavlen",
+    "Copied!" : "Kopiert!",
     "Federated Cloud" : "Sammenknyttet sky",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dele med alle som bruker en Nextcloud-server eller andre Open Cloud Mesh (OCM)-kompatible servere og tjenester! Bare legg inn deres ID for sammenknyttet sky i delingsdialogen. Det ser ut som person@cloud.example.com.",
     "Share it so your friends can share files with you:" : "Del den slik at venner kan dele filer med deg:",
@@ -40,28 +45,14 @@ OC.L10N.register(
     "Add to your website" : "Legg på nettsiden din",
     "Share with me via Nextcloud" : "Del med meg via Nextcloud",
     "HTML Code:" : "HTML-kode:",
-    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Del med meg gjennom min #Nextcloud ID for sammenknyttet sky, se {url}.",
-    "Share with me through my #Nextcloud Federated Cloud ID" : "Del med meg gjennom min #Nextcloud-ID for sammenknyttet sky",
-    "Cloud ID copied to the clipboard" : "Sky-ID kopiert til utklippstavlen",
-    "Copy to clipboard" : "Kopiert til utklippstavlen",
-    "Copied!" : "Kopiert!",
     "Cancel" : "Avbryt",
     "Add remote share" : "Legg til ekstern ressurs",
     "Remote share" : "Ekstern ressurs",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du å legge til ekstern ressurs {name} fra {owner}@{remote}?",
     "Remote share password" : "Passord for ekstern ressurs",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Deling av %1$s mislyktes, fordi dette elementet allerede er delt med bruker %2$s",
-    "Not allowed to create a federated share with the same user" : "Ikke tillatt å opprette en sammenknyttet skydeling med den samme brukeren",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Juster hvordan personer kan dele mellom servere. Dette inkluderer også delinger mellom personer på denne serveren hvis de bruker sammenknyttet deling.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillat brukere på denne serveren å sende delinger til andre servere (dette alternativet gir også WebDAV-tilgang til offentlige delinger)",
-    "Allow users on this server to receive shares from other servers" : "Tillat at brukere på denne serveren mottar delinger fra andre servere",
-    "Allow users on this server to send shares to groups on other servers" : "Tillat brukere på denne serveren å sende delinger til grupper på andre servere",
-    "Allow users on this server to receive group shares from other servers" : "Tillat brukere på denne serveren å motta gruppedelinger fra andre servere",
-    "Search global and public address book for users" : "Søk global og offentlige adressebøker etter brukere",
-    "Allow users to publish their data to a global and public address book" : "Tillat brukere å offentliggjøre deres data til en verdensomspennende og offentlig adressebok",
+    "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig",
     "Your Federated Cloud ID:" : "Din ID for sammenknyttet sky:",
     "Twitter" : "Twitter",
-    "Diaspora" : "Diaspora",
-    "Clipboard is not available" : "Utklippstavlen er ikke tilgjengelig"
+    "Diaspora" : "Diaspora"
 },
 "nplurals=2; plural=(n != 1);");
