@@ -43,8 +43,17 @@ OC.L10N.register(
     "Files" : "Fitxers",
     "A file or folder has been <strong>changed</strong>" : "S'ha <strong>modificat</strong> un fitxer o carpeta",
     "A favorite file or folder has been <strong>changed</strong>" : "S'ha <strong>modificat</strong> un fitxer o carpeta dels preferits",
+    "Failed to authorize" : "No s'ha pogut autoritzar",
+    "Invalid folder path" : "Camí de la carpeta no vàlid",
     "Folder not found" : "No s'ha trobat la carpeta",
-    "No favorites" : "No hi ha favorits",
+    "The file cannot be found" : "No s'ha trobat el fitxer",
+    "The destination path does not exist: %1$s" : "El camí de destí no existeix: %1$s",
+    "You do not have permission to create a file at the specified location" : "No teniu permís per crear fitxers a la ubicació especificada",
+    "The file could not be converted." : "No s'ha pogut convertir el fitxer.",
+    "Could not get relative path to converted file" : "No s'ha pogut obtenir el camí relatiu al fitxer convertit",
+    "Favorite files" : "Fitxers preferits",
+    "No favorites" : "No hi ha preferits",
+    "More favorites" : "Més preferits",
     "Upload (max. %s)" : "Puja (màx. %s)",
     "Accept" : "Accepta",
     "Reject" : "Rebutja",
@@ -61,69 +70,68 @@ OC.L10N.register(
     "in %s" : "%s",
     "Transferred from %1$s on %2$s" : "S'ha transferit de %1$s a %2$s",
     "Files compatibility" : "Compatibilitat de fitxers",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet restringir els noms de fitxers per garantir que els fitxers es puguin sincronitzar amb tots els clients. De manera predeterminada, es permeten tots els noms de fitxer vàlids a POSIX (per exemple, Linux o macOS).",
-    "Enforce Windows compatibility" : "Impulsar la compatibilitat amb Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Això bloquejarà els noms de fitxer no vàlids als sistemes Windows, com ara l'ús de noms reservats o caràcters especials. Però això no farà complir la compatibilitat de la distinció entre majúscules i minúscules.",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permet restringir els noms de fitxers per garantir que els fitxers es puguin sincronitzar amb tots els clients. Per defecte es permeten tots els noms de fitxer vàlids a POSIX (per exemple, Linux o macOS).",
+    "Enforce Windows compatibility" : "Força la compatibilitat amb Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Això bloquejarà els noms de fitxer no vàlids als sistemes Windows, com ara l'ús de noms reservats o caràcters especials. Però això no força la compatibilitat de la distinció entre majúscules i minúscules.",
     "File Management" : "Gestió de fitxers",
-    "Current directory path" : "Camí de la carpeta actual",
     "Home" : "Inici",
     "Target folder does not exist any more" : "La carpeta de destinació ja no existeix",
     "Reload current directory" : "Torna a carregar la carpeta actual",
     "Go to the \"{dir}\" directory" : "Ves a la carpeta «{dir}»",
-    "Drag and drop files here to upload" : "Arrossegueu i deixeu anar fitxers aquí per a pujar-los",
+    "Current directory path" : "Camí de la carpeta actual",
     "Your have used your space quota and cannot upload files anymore" : "Heu utilitzat la quota d'espai i ja no podeu pujar fitxers",
-    "You don’t have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
+    "You do not have permission to upload or create files here." : "No tens permís per pujar o crear arxius aquí.",
+    "Drag and drop files here to upload" : "Arrossegueu i deixeu anar fitxers aquí per a pujar-los",
     "Favorite" : "En els preferits",
     "Back" : "Torna",
     "Toggle selection for file \"{displayName}\"" : "Canvia la selecció per al fitxer «{displayName}»",
     "Toggle selection for folder \"{displayName}\"" : "Canvia la selecció per a la carpeta «{displayName}»",
     "File is loading" : "S'està carregant el fitxer",
     "Folder is loading" : "S'està carregant la carpeta",
-    "Rename file" : "Canvia el nom del fitxer",
     "Filename" : "Nom del fitxer",
     "Folder name" : "Nom de la carpeta",
     "This node is unavailable" : "Aquest node no està disponible",
     "Another entry with the same name already exists." : "Ja existeix una altra entrada amb el mateix nom.",
     "Invalid filename." : "Nom de fitxer no vàlid.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "S'ha canviat el nom de «{oldName}» a «{newName}»",
+    "Rename file" : "Canvia el nom del fitxer",
+    "Folder" : "Carpeta",
     "Pending" : "Pendent",
+    "Unknown date" : "Data desconeguda",
     "Clear filter" : "Esborra el filtre",
     "Modified" : "Darrera modificació",
     "Type" : "Tipus",
     "Active filters" : "Filtres actius",
     "Remove filter" : "Suprimeix el filtre",
     "Total rows summary" : "Resum de totes les files",
+    "Toggle selection for all files and folders" : "Canvia la selecció per a tots els fitxers i carpetes",
     "Name" : "Nom",
     "Size" : "Mida",
-    "Toggle selection for all files and folders" : "Canvia la selecció per a tots els fitxers i carpetes",
-    "Actions" : "Accions",
-    "(selected)" : "(seleccionat)",
-    "\"{displayName}\" failed on some elements " : "\"{displayName}\" ha fallat en alguns elements ",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ha fallat en alguns elements",
     "\"{displayName}\" batch action executed successfully" : "L'acció per lots «{displayName}» s'ha executat correctament",
     "\"{displayName}\" action failed" : "S'ha produït un error en l'acció «{displayName}»",
-    "{count} selected" : "Selecció: {count}",
+    "Actions" : "Accions",
+    "(selected)" : "(seleccionat)",
     "List of files and folders." : "Llista de fitxers i carpetes.",
+    "You have used your space quota and cannot upload files anymore." : "Heu utilitzat la quota d'espai i ja no podeu pujar fitxers.",
     "Column headers with buttons are sortable." : "Les capçaleres de columna amb botons es poder ordenar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Aquesta llista no es mostra completament per raons de rendiment. Es mostraran els fitxers a mesura que navegueu per la llista.",
     "File not found" : "No s'ha trobat el fitxer",
-    "Storage information" : "Informació d'emmagatzematge",
-    "Storage quota" : "Quota d'emmagatzematge",
+    "{count} selected" : "Selecció: {count}",
     "{usedQuotaByte} used" : "{usedQuotaByte} en ús",
     "{used} of {quota} used" : "{used} de {quota} en ús",
     "{relative}% used" : "{relative}% en ús",
     "Could not refresh storage stats" : "No s'han pogut actualitzar les estadístiques d'emmagatzematge",
     "Your storage is full, files can not be updated or synced anymore!" : "L'emmagatzematge està ple, els fitxers ja no es poden actualitzar ni sincronitzar!",
-    "Create" : "Crea",
+    "Storage information" : "Informació d'emmagatzematge",
+    "Storage quota" : "Quota d'emmagatzematge",
     "New folder" : "Carpeta nova",
     "Create new folder" : "Crea una carpeta",
     "This name is already in use." : "Aquest nom ja s'utilitza.",
+    "Create" : "Crea",
     "Fill template fields" : "Ompliu els camps de la plantilla",
-    "Submitting fields…" : "S'estan enviant camps…",
+    "Submitting fields …" : "S'estan enviant camps …",
     "Submit" : "Envia",
-    "Transfer ownership of a file or folder" : "Transferència de la propietat d'un fitxer o carpeta",
-    "Choose file or folder to transfer" : "Tria el fitxer o carpeta que voleu transferir",
-    "Change" : "Canvia",
-    "New owner" : "Propietari nou",
     "Choose a file or folder to transfer" : "Trieu el fitxer o carpeta que voleu transferir",
     "Transfer" : "Transfereix",
     "Transfer {path} to {userid}" : "Transfereix {path} a {userid}",
@@ -131,18 +139,27 @@ OC.L10N.register(
     "Unknown error" : "Error desconegut",
     "Ownership transfer request sent" : "S'ha enviat la sol·licitud de transferència de propietat",
     "Cannot transfer ownership of a file or folder you do not own" : "No es pot transferir la propietat d'un fitxer o carpeta que no és vostre",
+    "Transfer ownership of a file or folder" : "Transferència de la propietat d'un fitxer o carpeta",
+    "Choose file or folder to transfer" : "Tria el fitxer o carpeta que voleu transferir",
+    "Change" : "Canvia",
+    "New owner" : "Propietari nou",
+    "Keep {old}" : "Mantenir {old}",
+    "Keep without extension" : "Mantenir sense extensió",
+    "Use {new}" : "Utilitza {new}",
+    "Remove extension" : "Suprimeix l'extensió",
+    "Change file extension" : "Canvia l'extensió del fitxer",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Canviar l'extensió del fitxer de \"{old}\" a \"{new}\" pot fer que el fitxer sigui il·legible.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Suprimeix l'extensió de fitxer \"{old}\" pot fer que el fitxer sigui il·legible.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Afegir l'extensió del fitxer \"{new}\" pot fer que el fitxer sigui il·legible.",
+    "Do not show this dialog again." : "No torneu a mostrar aquest diàleg.",
     "Select file or folder to link to" : "Seleccioneu el fitxer o la carpeta que voleu enllaçar",
     "Choose {file}" : "Tria {file}",
-    "Loading current folder" : "S'està carregant la carpeta actual",
-    "Retry" : "Torna-ho a provar",
-    "No files in here" : "No hi ha cap fitxer aquí",
-    "Upload some content or sync with your devices!" : "Pugeu contingut o sincronitzeu els vostres dispositius!",
-    "Go back" : "Torna",
     "Share" : "Comparteix",
     "Shared by link" : "S'ha compartit amb un enllaç",
     "Shared" : "S'ha compartit",
     "Switch to list view" : "Canvia a la visualització de llista",
     "Switch to grid view" : "Canvia a la visualització de quadrícula",
+    "The file could not be found" : "No s'ha pogut trobar el fitxer",
     "Upload was cancelled by user" : "L'usuari ha cancel·lat la pujada",
     "Not enough free space" : "No hi ha prou espai lliure",
     "Operation is blocked by access control" : "L'operació està blocada pel control d'accés",
@@ -150,13 +167,20 @@ OC.L10N.register(
     "Error during upload, status code {status}" : "S'ha produït un error durant la pujada, el codi d'estat és {status}",
     "Unknown error during upload" : "S'ha produït un error desconegut durant la pujada",
     "\"{displayName}\" action executed successfully" : "L'acció «{displayName}» s'ha executat correctament",
-    "Filter filenames…" : "Filtra els noms de fitxer…",
+    "Loading current folder" : "S'està carregant la carpeta actual",
+    "Retry" : "Torna-ho a provar",
+    "No files in here" : "No hi ha cap fitxer aquí",
+    "Upload some content or sync with your devices!" : "Pugeu contingut o sincronitzeu els vostres dispositius!",
+    "Go back" : "Torna",
+    "Filter file names …" : "Filtra els noms dels fitxers …",
     "Views" : "Vistes",
     "Files settings" : "Paràmetres de Fitxers",
-    "File cannot be accessed" : "No es pot accedir al fitxer",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "No s'ha trobat el fitxer o no teniu permisos per a visualitzar-lo. Demaneu al remitent que el comparteixi.",
     "Your files" : "Els vostres fitxers",
     "Open in files" : "Obre a Fitxers",
+    "File cannot be accessed" : "No es pot accedir al fitxer",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "No s'ha trobat el fitxer o no teniu permisos per a visualitzar-lo. Demaneu al remitent que el comparteixi.",
+    "Clipboard is not available" : "El porta-retalls no està disponible",
+    "WebDAV URL copied to clipboard" : "S'ha copiat l'URL de WebDAV al porta-retalls",
     "Sort favorites first" : "Ordena primer els preferits",
     "Sort folders before files" : "Ordena les carpetes abans dels fitxers",
     "Show hidden files" : "Mostra els fitxers ocults",
@@ -169,25 +193,57 @@ OC.L10N.register(
     "Copy to clipboard" : "Copia-ho al porta-retalls",
     "Use this address to access your Files via WebDAV" : "Utilitzeu aquesta adreça per a accedir als vostres fitxers mitjançant WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si heu habilitat l'autenticació de doble factor, podeu crear i utilitzar una nova contrasenya d'aplicació fent clic aquí.",
+    "Warnings" : "Advertiments",
+    "Prevent warning dialogs from open or reenable them." : "Eviteu que s'obrin els diàlegs d'advertència o torneu-los a habilitar.",
+    "Show a warning dialog when changing a file extension." : "Mostra un diàleg d'avís quan es canvia una extensió de fitxer.",
     "Keyboard shortcuts" : "Dreceres de teclat",
+    "Speed up your Files experience with these quick shortcuts." : "Accelereu l'experiència Fitxers amb aquestes dreceres ràpides.",
+    "Open the actions menu for a file" : "Obre el menú d'accions per un fitxer",
+    "Rename a file" : "Canvia el nom del fitxer",
+    "Delete a file" : "Suprimeix el fitxer",
+    "Favorite or remove a file from favorites" : "Marca com a preferit o suprimeix un fitxer dels preferits",
+    "Manage tags for a file" : "Administra les etiquetes d'un fitxer",
     "Selection" : "Selecció",
+    "Select all files" : "Seleccioneu tots els fitxers",
+    "Deselect all files" : "Desseleccioneu tots els fitxers",
+    "Select or deselect a file" : "Seleccioneu o deseleccioneu un fitxer",
+    "Select a range of files" : "Seleccioneu un rang de fitxers",
     "Navigation" : "Navegació",
+    "Navigate to the parent folder" : "Navegueu a la carpeta principal",
+    "Navigate to the file above" : "Navegueu al fitxer de dalt",
+    "Navigate to the file below" : "Navegueu fins al fitxer següent",
+    "Navigate to the file on the left (in grid mode)" : "Navegueu fins al fitxer de l'esquerra (en mode de quadrícula)",
+    "Navigate to the file on the right (in grid mode)" : "Navegueu fins al fitxer de la dreta (en mode de quadrícula)",
     "View" : "Visualització",
-    "Clipboard is not available" : "El porta-retalls no està disponible",
-    "WebDAV URL copied to clipboard" : "S'ha copiat l'URL de WebDAV al porta-retalls",
+    "Toggle the grid view" : "Commuta la vista de la quadrícula",
+    "Open the sidebar for a file" : "Obriu la barra lateral d'un fitxer",
+    "Show those shortcuts" : "Mostra aquestes dreceres",
+    "You" : "Vós",
+    "Shared multiple times with different people" : "S'ha compartit diverses vegades amb persones diferents",
+    "Error while loading the file data" : "S'ha produït un error en carregar la informació del fitxer",
     "Owner" : "Propietat",
     "Remove from favorites" : "Suprimeix dels preferits",
     "Add to favorites" : "Afegeix als preferits",
     "Tags" : "Etiquetes",
-    "You" : "Vós",
-    "Shared multiple times with different people" : "S'ha compartit diverses vegades amb persones diferents",
-    "Unable to change the favourite state of the file" : "No s'ha pogut canviar l'estat de preferit del fitxer",
-    "Error while loading the file data" : "S'ha produït un error en carregar la informació del fitxer",
+    "Blank" : "En blanc",
+    "Unable to create new file from template" : "No s'ha pogut crear el fitxer a partir de la plantilla",
     "Pick a template for {name}" : "Trieu una plantilla per a {name}",
     "Create a new file with the selected template" : "Crea un fitxer amb la plantilla seleccionada",
     "Creating file" : "S'està creant el fitxer",
-    "Blank" : "En blanc",
-    "Unable to create new file from template" : "No s'ha pogut crear el fitxer a partir de la plantilla",
+    "Save as {displayName}" : "Desa com a {displayName}",
+    "Save as …" : "Anomena i desa …",
+    "Converting files …" : "Convertint fitxers …",
+    "Failed to convert files: {message}" : "No s'han pogut convertir els fitxers: {message}",
+    "All files failed to be converted" : "No s'han pogut convertir tots els fitxers",
+    "One file could not be converted: {message}" : "No s'ha pogut convertir un fitxer: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["No s'ha pogut convertir un fitxer","No s’han pogut convertir %n fitxers"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Un fitxer s'ha convertit correctament","%n fitxers s'han convertit correctament"],
+    "Files successfully converted" : "Els fitxers s'han convertit correctament",
+    "Failed to convert files" : "No s'han pogut convertir els fitxers",
+    "Converting file …" : "S'està convertint el fitxer …",
+    "File successfully converted" : "El fitxer s'ha convertit correctament",
+    "Failed to convert file: {message}" : "No s'ha pogut convertir el fitxer: {message}",
+    "Failed to convert file" : "No s'ha pogut convertir el fitxer",
     "Deletion cancelled" : "S'ha cancel·lat la supressió",
     "Leave this share" : "Abandona aquest element compartit",
     "Leave these shares" : "Abandona aquests elements compartits",
@@ -204,10 +260,8 @@ OC.L10N.register(
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Esteu a punt de suprimir {count} element","Esteu a punt de suprimir {count} elements"],
     "Confirm deletion" : "Confirma la supressió",
     "Cancel" : "Cancel·la",
-    "Edit file locally" : "Edita el fitxer localment",
-    "Edit online" : "Edita en remot",
-    "Failed to redirect to client" : "No s'ha pogut redirigir al client",
-    "Edit locally" : "Edita localment",
+    "Moving \"{source}\" to \"{destination}\" …" : "S'està movent \"{source}\" a \"{destination}”…",
+    "Copying \"{source}\" to \"{destination}\" …" : "S'està copiant \"{source}\" a \"{destination}” …",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "No podeu moure un fitxer o carpeta a la mateixa carpeta o a una subcarpeta de la mateixa carpeta",
     "(copy)" : "(còpia)",
     "(copy %n)" : "(còpia %n)",
@@ -226,6 +280,12 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "S'ha cancel·lat l'operació de desplaçament o còpia",
     "Open folder {displayName}" : "Obre la carpeta {displayName}",
     "Open in Files" : "Obre a Fitxers",
+    "Open file locally" : "Obre el fitxer en local",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Ara s'hauria d'obrir el fitxer al dispositiu. Si no és així, comproveu que teniu instal·lada l'aplicació d'escriptori.",
+    "Retry and close" : "Torna-ho a provar i tanca",
+    "Open online" : "Obre en línia",
+    "Failed to redirect to client" : "No s'ha pogut redirigir al client",
+    "Open locally" : "Obre en local",
     "Rename" : "Canvia el nom",
     "Open details" : "Obre els detalls",
     "View in folder" : "Visualitza-ho en la carpeta",
@@ -240,7 +300,7 @@ OC.L10N.register(
     "PDFs" : "PDFs",
     "Folders" : "Carpetes",
     "Audio" : "Àudio",
-    "Photos and images" : "Fotos i imatges",
+    "Photos and images" : "Fotografies i imatges",
     "Videos" : "Vídeos",
     "New folder creation cancelled" : "S'ha cancel·lat la creació de carpetes noves",
     "Created new folder \"{name}\"" : "S'ha creat la carpeta nova «{name}»",
@@ -266,14 +326,12 @@ OC.L10N.register(
     "This operation is forbidden" : "Aquesta operació no està permesa",
     "This directory is unavailable, please check the logs or contact the administrator" : "Aquesta carpeta no està disponible. Consulteu els registres o contacteu amb l'administrador",
     "Storage is temporarily not available" : "L'emmagatzematge no està disponible temporalment",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetes"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fitxer","{fileCount} fitxers"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fitxer i {folderCount} carpeta","1 fitxer i {folderCount} carpetes"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fitxer i 1 carpeta","{fileCount} fitxers i 1 carpeta"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxers i {folderCount} carpetes",
+    "Unexpected error: {error}" : "Error inesperat: {error}",
+    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
+    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
     "Filename must not be empty." : "El nom del fitxer no ha d'estar buit.",
-    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no es permet dins d'un nom de fitxer.",
-    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" és un nom reservat i no es permet per als noms de fitxer.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no és permès dins d'un nom de fitxer.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" és un nom reservat i no és permès per als noms de fitxer.",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" no és un tipus de fitxer permès.",
     "Filenames must not end with \"{extension}\"." : "Els noms de fitxer no han d'acabar amb \"{extension}\".",
     "List of favorite files and folders." : "Llista de fitxers i carpetes preferits.",
@@ -282,7 +340,7 @@ OC.L10N.register(
     "All files" : "Tots els fitxers",
     "List of your files and folders." : "Llista dels vostres fitxers i carpetes.",
     "All folders" : "Totes les carpetes",
-    "Personal Files" : "FItxers personals",
+    "Personal files" : "Fitxers personals",
     "List of your files and folders that are not shared." : "Llista dels vostres fitxers i carpetes que no compartiu.",
     "No personal files found" : "No s'ha trobat cap fitxer personal",
     "Files that are not shared will show up here." : "Els fitxers que no compartiu es mostraran aquí.",
@@ -290,7 +348,6 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Llista de fitxers i carpetes modificats recentment.",
     "No recently modified files" : "No hi ha cap fitxer modificat recentment",
     "Files and folders you recently modified will show up here." : "Els fitxers i les carpetes que heu modificat recentment es mostraran aquí.",
-    "You do not have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
     "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
     "Select all" : "Selecciona-ho tot",
     "Upload too large" : "La pujada és massa gran",
@@ -318,6 +375,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "S'ha produït un error en recopilar els fragments, el codi d'estat és {status}",
     "Choose target folder" : "Trieu la carpeta de destinació",
     "Set reminder" : "Defineix un recordatori",
+    "Edit locally" : "Edita localment",
     "Open" : "Obre",
     "Could not load info for file \"{file}\"" : "No s'ha pogut carregar la informació del fitxer «{file}»",
     "Details" : "Detalls",
@@ -344,10 +402,9 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "S'ha produït un error en suprimir el fitxer «{fileName}».",
     "No search results in other folders for {tag}{filter}{endtag}" : "No hi ha cap resultat de cerca en altres carpetes per a {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Introduïu més de dos caràcters per a cercar en altres carpetes",
-    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
-    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
     "{dirs} and {files}" : "{dirs} i {files}",
     "_including %n hidden_::_including %n hidden_" : ["incloent-hi %n element ocult","incloent-hi %n elements ocults"],
+    "You do not have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
     "_Uploading %n file_::_Uploading %n files_" : ["S'està pujant %n fitxer","S'estan pujant %n fitxers"],
     "New" : "Crea",
     "New file/folder menu" : "Menú de fitxer o carpeta nova",
@@ -367,40 +424,38 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'emmagatzematge extern «{mountPoint}» està gairebé ple ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "L'emmagatzematge està gairebé ple ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincideix amb «{filter}»","coincideixen amb «{filter}»"],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "S'ha copiat l'enllaç directe (només funciona per als usuaris que tenen accés a aquest fitxer o carpeta)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "S'ha copiat l'enllaç directe (només funciona per a les persones que tenen accés a aquest fitxer o carpeta)",
     "Path" : "Camí",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "En els preferits",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copia l'enllaç directe (només funciona per als usuaris que tinguin accés a aquest fitxer o carpeta)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Copia l'enllaç directe (només funciona per a les persones que tinguin accés a aquest fitxer o carpeta)",
     "Upload file" : "Puja un fitxer",
     "Not favorited" : "No s'inclou en els preferits",
     "An error occurred while trying to update the tags" : "S'ha produït un error en intentar actualitzar les etiquetes",
-    "\"remote user\"" : "«usuari remot»",
-    "{newName} already exists." : "{newName} ja existeix.",
-    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" no es permet dins d'un nom de fitxer.",
-    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" és un nom de fitxer o carpeta prohibit.",
-    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" no és un tipus de fitxer permès.",
-    "Filenames must not end with \"{segment}\"." : "Els noms de fitxer no han d'acabar amb \"{segment}\".",
-    "Name cannot be empty" : "El nom no pot estar buit",
-    "Another entry with the same name already exists" : "Ja existeix una altra entrada amb aquest nom",
-    "Could not rename \"{oldName}\", it does not exist any more" : "No s'ha pogut canviar el nom de «{oldName}», ja no existeix",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nom «{newName}» ja està en ús en la carpeta «{dir}». Trieu un nom diferent.",
-    "Could not rename \"{oldName}\"" : "No s'ha pogut canviar el nom de «{oldName}»",
+    "You don't have permission to upload or create files here." : "No teniu permís per pujar o crear fitxers aquí.",
     "Storage informations" : "Informació d'emmagatzematge",
     "Choose file" : "Tria el fitxer",
     "Go to the previous folder" : "Torna a la carpeta anterior",
     "Open the files app settings" : "Obre els paràmetres de l'aplicació Fitxers",
-    "You might not have have permissions to view it, ask the sender to share it" : "És possible que no tingueu permisos per a visualitzar-lo; demaneu al remitent que el comparteixi",
-    "The files is locked" : "El fitxer està blocat",
+    "Unable to change the favourite state of the file" : "No s'ha pogut canviar l'estat de preferit del fitxer",
+    "Edit file locally" : "Edició del fitxer localment",
+    "Edit online" : "Edició en remot",
     "Create new templates folder" : "Crea la carpeta de plantilles",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetes"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fitxer","{fileCount} fitxers"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fitxer i {folderCount} carpeta","1 fitxer i {folderCount} carpetes"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fitxer i 1 carpeta","{fileCount} fitxers i 1 carpeta"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxers i {folderCount} carpetes",
     "List of favorites files and folders." : "Llista de fitxers i carpetes preferits.",
-    "Toggle %1$s sublist" : "Canvia la subllista de %1$s",
+    "Personal Files" : "FItxers personals",
     "Text file" : "Fitxer de text",
     "New text file.txt" : "Fitxer de text nou.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "S'ha copiat l'enllaç directe (només funciona per a les persones que tenen accés a aquest fitxer o carpeta)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copia l'enllaç directe (només funciona per a les persones que tinguin accés a aquest fitxer o carpeta)",
     "Favored" : "Afavorit",
     "Favor" : "Afavorir",
-    "Not favored" : "No afavorit"
+    "Not favored" : "No afavorit",
+    "Submitting fields…" : "S'estan enviant camps…",
+    "Filter filenames…" : "Filtra els noms de fitxer…",
+    "{count} files could not be converted" : "No s'han pogut convertir {count} fitxers",
+    "{count} files successfully converted" : "{count} fitxers convertits correctament"
 },
 "nplurals=2; plural=(n != 1);");
