@@ -61,25 +61,25 @@ OC.L10N.register(
     "Enforce Windows compatibility" : "Επιβολή συμβατότητας με Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Αυτό θα αποκλείσει ονόματα αρχείων που δεν είναι έγκυρα σε συστήματα Windows, όπως η χρήση δεσμευμένων ονομάτων ή ειδικών χαρακτήρων. Αλλά αυτό δεν θα επιβάλει τη συμμόρφωση ως προς την διάκριση πεζών-κεφαλαίων.",
     "File Management" : "Διαχείριση αρχείων",
-    "Current directory path" : "Τρέχουσα διαδρομή καταλόγου",
     "Home" : "Αρχική",
     "Target folder does not exist any more" : "Ο φάκελος προορισμού δεν υπάρχει πια",
     "Reload current directory" : "Επαναφόρτωση τρέχοντος καταλόγου",
     "Go to the \"{dir}\" directory" : "Μετάβαση στον κατάλογο \"{dir}\"",
-    "Drag and drop files here to upload" : "Σύρετε και αφήστε αρχεία εδώ για να τα μεταφορτώσετε",
+    "Current directory path" : "Τρέχουσα διαδρομή καταλόγου",
     "Your have used your space quota and cannot upload files anymore" : "Έχετε χρησιμοποιήσει το όριο χώρου σας και δεν μπορείτε να μεταφορτώσετε αρχεία πλέον",
-    "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
+    "Drag and drop files here to upload" : "Σύρετε και αφήστε αρχεία εδώ για να τα μεταφορτώσετε",
     "Favorite" : "Αγαπημένο",
     "Back" : "Επιστροφή",
     "Toggle selection for file \"{displayName}\"" : "Εναλλαγή επιλογής για το αρχείο \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Εναλλαγή επιλογής για τον φάκελο \"{displayName}\"",
-    "Rename file" : "Μετονομασία αρχείου",
     "Filename" : "Όνομα αρχείου",
     "Folder name" : "Όνομα φακέλου",
     "This node is unavailable" : "Αυτός ο κόμβος δεν είναι διαθέσιμος",
     "Another entry with the same name already exists." : "Μια άλλη καταχώρηση με το ίδιο όνομα υπάρχει ήδη.",
     "Invalid filename." : "Μη έγκυρο όνομα αρχείου",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Μετονομασία του \"{oldName}\" σε \"{newName}\"",
+    "Rename file" : "Μετονομασία αρχείου",
+    "Folder" : "Φάκελος",
     "Pending" : "Εκκρεμεί",
     "Clear filter" : "Εκκαθάριση φίλτρου",
     "Modified" : "Τροποποιήθηκε",
@@ -87,33 +87,28 @@ OC.L10N.register(
     "Active filters" : "Ενεργά φίλτρα",
     "Remove filter" : "Αφαίρεση φίλτρου",
     "Total rows summary" : "Συνολική σύνοψη γραμμών",
+    "Toggle selection for all files and folders" : "Εναλλαγή επιλογής για όλα τα αρχεία και τους φακέλους",
     "Name" : "Όνομα",
     "Size" : "Μέγεθος",
-    "Toggle selection for all files and folders" : "Εναλλαγή επιλογής για όλα τα αρχεία και τους φακέλους",
-    "Actions" : "Ενέργειες",
-    "\"{displayName}\" failed on some elements " : "\"{displayName}\" απέτυχε σε ορισμένα στοιχεία",
     "\"{displayName}\" batch action executed successfully" : "Η μαζική ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
     "\"{displayName}\" action failed" : "Η ενέργεια του \"{displayName}\" απέτυχε",
-    "{count} selected" : "{count} έχουν επιλεγεί",
+    "Actions" : "Ενέργειες",
     "List of files and folders." : "Λίστα αρχείων και φακέλων.",
     "Column headers with buttons are sortable." : "Οι επικεφαλίδες στηλών με κουμπιά είναι ταξινομήσιμες.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Η λίστα αυτή δεν εμφανίζεται πλήρως για λόγους απόδοσης. Τα αρχεία θα εμφανίζονται καθώς πλοηγείστε στη λίστα.",
     "File not found" : "Δε βρέθηκε το αρχείο",
-    "Storage information" : "Πληροφορίες αποθήκευσης",
+    "{count} selected" : "{count} έχουν επιλεγεί",
     "{usedQuotaByte} used" : "{usedQuotaByte} χρησιμοποιείται",
     "{used} of {quota} used" : "Χρήση {used} από {quota} ",
     "{relative}% used" : "{relative}% χρησιμοποιείται",
     "Could not refresh storage stats" : "Δεν ήταν δυνατή η ανανέωση των στατιστικών αποθήκευσης",
     "Your storage is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πια!",
-    "Create" : "Δημιουργία",
+    "Storage information" : "Πληροφορίες αποθήκευσης",
     "New folder" : "Νέος φάκελος",
     "Create new folder" : "Δημιουργία νέου φακέλου",
     "This name is already in use." : "Αυτό το όνομα χρησιμοποιείται ήδη.",
+    "Create" : "Δημιουργία",
     "Submit" : "Υποβολή",
-    "Transfer ownership of a file or folder" : "Μεταβίβαση κυριότητας αρχείου ή φακέλου",
-    "Choose file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
-    "Change" : "Αλλαγή",
-    "New owner" : "Νέος κάτοχος",
     "Choose a file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
     "Transfer" : "Μεταφορά",
     "Transfer {path} to {userid}" : "Μεταφορά {path} στον {userid}",
@@ -121,13 +116,12 @@ OC.L10N.register(
     "Unknown error" : "Άγνωστο σφάλμα",
     "Ownership transfer request sent" : "Αποστολή αίτησης μεταβίβασης κυριότητας",
     "Cannot transfer ownership of a file or folder you do not own" : "Δεν είναι δυνατή η μεταβίβαση της κυριότητας ενός αρχείου ή φακέλου που δε σας ανήκει",
+    "Transfer ownership of a file or folder" : "Μεταβίβαση κυριότητας αρχείου ή φακέλου",
+    "Choose file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
+    "Change" : "Αλλαγή",
+    "New owner" : "Νέος κάτοχος",
     "Select file or folder to link to" : "Επιλέξτε αρχείο ή φάκελο για σύνδεση",
     "Choose {file}" : "Επιλέξτε {file}",
-    "Loading current folder" : "Φόρτωση τρέχοντος φακέλου",
-    "Retry" : "Δοκιμή ξανά",
-    "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
-    "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
-    "Go back" : "Επιστροφή",
     "Share" : "Διαμοιρασμός",
     "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
     "Shared" : "Κοινόχρηστα",
@@ -140,13 +134,19 @@ OC.L10N.register(
     "Error during upload, status code {status}" : "Σφάλμα κατά τη μεταφόρτωση, κωδικός κατάστασης {status}",
     "Unknown error during upload" : "Άγνωστο σφάλμα κατά τη μεταφόρτωση",
     "\"{displayName}\" action executed successfully" : "Η ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
-    "Filter filenames…" : "Φιλτράρετε τα ονόματα αρχείων...",
+    "Loading current folder" : "Φόρτωση τρέχοντος φακέλου",
+    "Retry" : "Δοκιμή ξανά",
+    "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
+    "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
+    "Go back" : "Επιστροφή",
     "Views" : "Προβολές",
     "Files settings" : "Ρυθμίσεις αρχείων",
-    "File cannot be accessed" : "Δεν είναι δυνατή η πρόσβαση στο αρχείο",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Το αρχείο δεν βρέθηκε ή δεν έχετε δικαιώματα προβολής του. Ζητήστε από τον αποστολέα να το μοιράσει.",
     "Your files" : "Τα αρχεία σας",
     "Open in files" : "Άνοιγμα στα αρχεία",
+    "File cannot be accessed" : "Δεν είναι δυνατή η πρόσβαση στο αρχείο",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Το αρχείο δεν βρέθηκε ή δεν έχετε δικαιώματα προβολής του. Ζητήστε από τον αποστολέα να το μοιράσει.",
+    "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
+    "WebDAV URL copied to clipboard" : "Ο σύνδεσμος WebDAV αντιγράφηκε στο πρόχειρο",
     "Sort favorites first" : "Ταξινόμηση των αγαπημένων πρώτα",
     "Sort folders before files" : "Ταξινόμηση φακέλων πριν από τα αρχεία",
     "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
@@ -161,20 +161,17 @@ OC.L10N.register(
     "Selection" : "Επιλογή",
     "Navigation" : "Πλοήγηση",
     "View" : "Προβολή",
-    "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
-    "WebDAV URL copied to clipboard" : "Ο σύνδεσμος WebDAV αντιγράφηκε στο πρόχειρο",
+    "You" : "Εσύ",
+    "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
     "Owner" : "Κάτοχος",
     "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
     "Add to favorites" : "Προσθήκη στα αγαπημένα",
     "Tags" : "Ετικέτες",
-    "You" : "Εσύ",
-    "Unable to change the favourite state of the file" : "Αδυναμία αλλαγής αγαπημένης κατάστασης αρχείου",
-    "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
+    "Blank" : "Κενό",
+    "Unable to create new file from template" : "Δεν είναι δυνατή η δημιουργία νέου αρχείου από το πρότυπο",
     "Pick a template for {name}" : "Επιλέξτε ένα πρότυπο για {name}",
     "Create a new file with the selected template" : "Δημιουργήστε ένα νέο αρχείο με το επιλεγμένο πρότυπο",
     "Creating file" : "Δημιουργία αρχείου",
-    "Blank" : "Κενό",
-    "Unable to create new file from template" : "Δεν είναι δυνατή η δημιουργία νέου αρχείου από το πρότυπο",
     "Deletion cancelled" : "Διαγραφή ακυρώθηκε",
     "Leave this share" : "Αποχώρηση από αυτό το κοινόχρηστο",
     "Leave these shares" : "Αποχώρηση από αυτά τα κοινόχρηστα",
@@ -188,8 +185,6 @@ OC.L10N.register(
     "Delete" : "Διαγραφή",
     "Confirm deletion" : "Επιβεβαίωση διαγραφής",
     "Cancel" : "Ακύρωση",
-    "Failed to redirect to client" : "Αποτυχία ανακατεύθυνσης στον πελάτη",
-    "Edit locally" : "Επεξεργασία τοπικά",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Δεν μπορείτε να μετακινήσετε ένα αρχείο/φάκελο στον εαυτό του ή σε έναν υποφάκελο του ίδιου του φακέλου.",
     "(copy)" : "(αντιγραφή)",
     "(copy %n)" : "(αντιγραφή %n)",
@@ -207,6 +202,7 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "Ακυρώθηκε η λειτουργία μετακίνησης ή αντιγραφής",
     "Open folder {displayName}" : "Άνοιγμα φακέλου {displayName}",
     "Open in Files" : "Άνοιγμα στα Αρχεία",
+    "Failed to redirect to client" : "Αποτυχία ανακατεύθυνσης στον πελάτη",
     "Rename" : "Μετονομασία",
     "Open details" : "Άνοιγμα λεπτομερειών",
     "View in folder" : "Προβολή στον φάκελο",
@@ -216,7 +212,9 @@ OC.L10N.register(
     "This year ({year})" : "Αυτό το έτος ({year})",
     "Last year ({year})" : "Το περασμένο έτος ({year})",
     "Documents" : "Έγγραφα",
+    "Presentations" : "Παρουσιάσεις",
     "Audio" : "Ήχος",
+    "Photos and images" : "Φωτογραφίες και εικόνες",
     "Videos" : "Βίντεο",
     "Created new folder \"{name}\"" : "Δημιουργήθηκε νέος φάκελος \"{name}\"",
     "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
@@ -235,11 +233,8 @@ OC.L10N.register(
     "This operation is forbidden" : "Αυτή η λειτουργία απαγορεύεται",
     "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλούμε ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
     "Storage is temporarily not available" : "Μη διαθέσιμος χώρος αποθήκευσης προσωρινά",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} φάκελος","{folderCount} φακέλοι"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} αρχείο","{fileCount} αρχεία"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 αρχείο και {folderCount} φάκελος","1 αρχείο και {folderCount} φακέλοι"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} αρχείο και 1 φάκελος","{fileCount} αρχεία και 1 φάκελος"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} αρχεία και {folderCount} φακέλοι",
+    "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
+    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
     "Filename must not be empty." : "Το όνομα αρχείου δεν πρέπει να είναι κενό.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" δεν επιτρέπεται μέσα σε όνομα αρχείου.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" είναι δεσμευμένο όνομα και δεν επιτρέπεται για ονόματα αρχείων.",
@@ -249,7 +244,7 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα θα εμφανιστούν εδώ",
     "All files" : "Όλα τα αρχεία",
     "List of your files and folders." : "Λίστα των αρχείων και φακέλων σας.",
-    "Personal Files" : "Προσωπικά Αρχεία",
+    "Personal files" : "Προσωπικά αρχεία",
     "List of your files and folders that are not shared." : "Λίστα αρχείων και φακέλων που δεν είναι κοινόχρηστα.",
     "No personal files found" : "Δε βρέθηκαν προσωπικά αρχεία",
     "Files that are not shared will show up here." : "Τα αρχεία που δεν είναι κοινόχρηστα θα εμφανίζονται εδώ.",
@@ -257,7 +252,6 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Λίστα των πρόσφατα τροποποιημένων αρχείων και φακέλων.",
     "No recently modified files" : "Δεν υπάρχουν πρόσφατα τροποποιημένα αρχεία",
     "Files and folders you recently modified will show up here." : "Εδώ θα εμφανίζονται τα αρχεία και οι φάκελοι που τροποποιήσατε πρόσφατα.",
-    "You do not have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
     "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
     "Select all" : "Επιλογή όλων",
     "Upload too large" : "Πολύ μεγάλο αρχείο προς μεταφόρτωση",
@@ -285,6 +279,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Σφάλμα κατά την συλλογή τμημάτων, κωδικός κατάστασης {status}",
     "Choose target folder" : "Επιλογή φακέλου προορισμού",
     "Set reminder" : "Προσθήκη υπενθύμισης",
+    "Edit locally" : "Επεξεργασία τοπικά",
     "Open" : "Άνοιγμα",
     "Could not load info for file \"{file}\"" : "Αδυναμία φόρτωσης πληροφοριών για το αρχείο \"{file}\"",
     "Details" : "Λεπτομέρειες",
@@ -311,10 +306,9 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Σφάλμα διαγραφής του \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Κανένα αποτέλεσμα αναζήτησης σε άλλους φακέλους για {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Εισαγάγετε περισσότερους από δύο χαρακτήρες για αναζήτηση σε άλλους φακέλους",
-    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
-    "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
     "{dirs} and {files}" : "{dirs} και {files}",
     "_including %n hidden_::_including %n hidden_" : ["περιλαμβάνεται %n κρυφό","περιλαμβάνονται %n κρυφά"],
+    "You do not have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
     "_Uploading %n file_::_Uploading %n files_" : ["Μεταφόρτωση %n αρχείου","Μεταφόρτωση %n αρχείων"],
     "New" : "Νέα",
     "New file/folder menu" : "Μενού νέου αρχείου/φακέλου",
@@ -334,33 +328,30 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ο εξωτερικός χώρος αποθήκευσης \"{mountPoint}\" είναι σχεδόν πλήρης ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Ο αποθηκευτικός σας χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Ταιριάζει \"{filter}\"","Ταιριάζουν \"{filter}\""],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Ο άμεσος σύνδεσμος αντιγράφηκε (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση σε αυτό το αρχείο/φάκελο)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Ο άμεσος σύνδεσμος αντιγράφηκε (λειτουργεί μόνο για άτομα που έχουν πρόσβαση σε αυτό το αρχείο/φάκελο)",
     "Path" : "Διαδρομή",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Αγαπημένα",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση στο αρχείο/φάκελο)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για άτομα που έχουν πρόσβαση στο αρχείο/φάκελο)",
     "Upload file" : "Μεταφόρτωση αρχείου",
     "Not favorited" : "Δεν είναι αγαπημένο",
     "An error occurred while trying to update the tags" : "Ένα σφάλμα προέκυψε κατά τη διάρκεια ενημέρωσης των ετικετών",
-    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
-    "{newName} already exists." : "Το {newName} υπάρχει ήδη.",
-    "Name cannot be empty" : "Το όνομα δεν μπορεί να είναι κενό",
-    "Another entry with the same name already exists" : "Υπάρχει ήδη μια άλλη καταχώρηση με το ίδιο όνομα",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\", δεν υπάρχει πλέον",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{newName}\" χρησιμοποιείται ήδη στον φάκελο \"{dir}\". Παρακαλώ επιλέξτε ένα διαφορετικό όνομα.",
-    "Could not rename \"{oldName}\"" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\"",
     "Storage informations" : "Πληροφορίες αποθήκευσης",
     "Choose file" : "Επιλέξτε αρχείο",
     "Go to the previous folder" : "Μετάβαση στον προηγούμενο φάκελο",
     "Open the files app settings" : "Ανοίξτε τις ρυθμίσεις της εφαρμογής αρχείων",
-    "You might not have have permissions to view it, ask the sender to share it" : "Μπορεί να μην έχετε δικαίωμα για να το δείτε. Ζητήστε από τον αποστολέα να το μοιραστεί",
-    "The files is locked" : "Το αρχείο είναι κλειδωμένο",
+    "Unable to change the favourite state of the file" : "Αδυναμία αλλαγής αγαπημένης κατάστασης αρχείου",
+    "Edit file locally" : "Επεξεργασία αρχείου τοπικά",
     "Create new templates folder" : "Δημιουργία νέου φακέλου προτύπων",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} φάκελος","{folderCount} φακέλοι"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} αρχείο","{fileCount} αρχεία"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 αρχείο και {folderCount} φάκελος","1 αρχείο και {folderCount} φακέλοι"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} αρχείο και 1 φάκελος","{fileCount} αρχεία και 1 φάκελος"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} αρχεία και {folderCount} φακέλοι",
     "List of favorites files and folders." : "Λίστα αγαπημένων αρχείων και φακέλων.",
-    "Toggle %1$s sublist" : "Εναλλαγή %1$s σε υπολίστα",
+    "Personal Files" : "Προσωπικά Αρχεία",
     "Text file" : "Αρχείο κειμένου",
     "New text file.txt" : "Νέο αρχείο file.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Ο άμεσος σύνδεσμος αντιγράφηκε (λειτουργεί μόνο για άτομα που έχουν πρόσβαση σε αυτό το αρχείο/φάκελο)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για άτομα που έχουν πρόσβαση στο αρχείο/φάκελο)"
+    "Filter filenames…" : "Φιλτράρετε τα ονόματα αρχείων..."
 },
 "nplurals=2; plural=(n != 1);");
