@@ -2,32 +2,46 @@ OC.L10N.register(
     "viewer",
     {
     "Viewer" : "Skatītājs",
-    "Simple file viewer with slideshow for media" : "Vienkāršs datņu skatītājs ar slaidrādi multividei",
+    "Simple file viewer with slideshow for media" : "Vienkāršs datņu skatītājs ar slīdrādi informācijas nesējiem",
     "Error loading {name}" : "Kļūda ielādējot {name}",
+    "Unsaved changes" : "Nesaglabātas izmaiņas",
+    "Your browser does not support videos." : "Pārlūks nenodrošina video",
     "Edit" : "Labot",
+    "Exit full screen" : "Iziet no pilnekrāna",
     "Open sidebar" : "Atvērt sānjoslu",
     "Download" : "Lejupielādēt",
-    "Delete" : "Dzēst",
+    "Delete" : "Izdzēst",
     "View" : "Skats",
     "Name" : "Vārds",
     "Save" : "Saglabāt",
     "Save as" : "Saglabāt kā",
     "Back" : "Atpakaļ",
+    "Loading …" : "Ielādē…",
     "Reset" : "Atiestatīt",
     "Cancel" : "Atcelt",
-    "Continue" : "Turpināt",
+    "Apply" : "Apstiprināt",
+    "Warning" : "Brīdinājums",
+    "Confirm" : "Apstiprināt",
     "Undo" : "Atsaukt",
     "Redo" : "Atcelt atsaukšanu",
+    "Filters" : "Filtri",
+    "Watermark" : "Ūdenszīme",
+    "are not images" : "nav attēli",
+    "is not an image" : "nav attēls",
     "Original" : "Oriģināls",
     "Custom" : "Pielāgots",
+    "Landscape" : "Ainava",
+    "Portrait" : "Portrets",
     "Value" : "Vērtība",
     "Image" : "Attēli",
     "Text" : "Teksts",
     "Size" : "Izmērs",
     "Save image as" : "Saglabāt attēlu kā",
+    "Name is required." : "Vārds ir nepieciešams.",
     "Quality" : "Kvalitāte",
     "Saved image size (width x height)" : "Saglabātā attēla izmērs (platums x augstums)",
     "Actual size (100%)" : "Faktiskais izmērs (100%)",
-    "Fit size" : "Atbilst izmēram"
+    "Fit size" : "Atbilst izmēram",
+    "Menu" : "Izvēlne"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
