@@ -61,10 +61,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (tidak kompatibel)",
     "The following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
     "Already up to date" : "Sudah yang terbaru",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Peladen web Anda belum diatur sesuai untuk sinkronisasi berkas, karena antarmuka WebDAV tidak berfungsi.",
     "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP header \"{header}\" tidak sesuai tersetel seperti \"{expected}\". Hal ini berpotensi risiko keamanan dan kerahasiaan. Direkomendasikan untuk dapat disesuaikan mengikuti anjuran.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP header \"{header}\" tidak sesuai tersetel seperti \"{expected}\". Beberapa fitur mungkin akan tidak berfungsi dengan baik. Direkomendasikan untuk dapat disesuaikan mengikuti anjuran.",
     "unknown text" : "teks tidak diketahui",
     "Hello world!" : "Halo dunia!",
     "sunny" : "cerah",
@@ -81,77 +78,91 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Pembaruan gagal. Laporkan masalah ini ke <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitas Nextcloud</a>.",
     "Continue to {productName}" : "Lanjutkan ke {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Pembaruan berhasil. Mengarahkan Anda ke {productName} dalam hitungan detik."],
+    "Apps" : "Aplikasi",
     "More apps" : "Aplikasi lainnya",
+    "No" : "Tidak",
+    "Yes" : "Ya",
+    "Failed to add the public link to your Nextcloud" : "Gagal menambah tautan publik ke Nextcloud Anda",
+    "Start typing to search" : "Mulai mengetik untuk mencari",
+    "Today" : "Hari ini",
+    "Places" : "Tempat",
+    "People" : "Orang",
+    "Load more results" : "Muat lebih banyak hasil",
     "Log in" : "Masuk",
     "Logging in …" : "Log masuk...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Terdeteksi multipel percobaan log masuk tidak valid dari IP Anda. Pencekalan log masuk berikutnya dilakukan hingga 30 detik.",
     "Server side authentication failed!" : "Otentikasi dari sisi server gagal!",
     "Please contact your administrator." : "Silakan hubungi administrator Anda.",
     "An internal error occurred." : "Terjadi kesalahan internal.",
     "Please try again or contact your administrator." : "Mohon coba lagi atau hubungi administrator Anda.",
     "Password" : "Kata Sandi",
-    "Wrong username or password." : "Nama pengguna atau kata sandi salah.",
-    "User disabled" : "Pengguna dinonaktifkan",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Terdeteksi multipel percobaan log masuk tidak valid dari IP Anda. Pencekalan log masuk berikutnya dilakukan hingga 30 detik.",
     "Log in with a device" : "Log masuk dengan perangkat",
-    "Username or email" : "Nama pengguna atau surel",
     "Your account is not setup for passwordless login." : "Akun Anda tidak diatur untuk masuk tanpa kata sandi.",
-    "Browser not supported" : "Peramban tidak didukung",
-    "Passwordless authentication is not supported in your browser." : "Otentikasi tanpa kata sandi tidak didukung peramban Anda.",
     "Your connection is not secure" : "Koneksi Anda tidak aman",
     "Passwordless authentication is only available over a secure connection." : "Otentikasi tanpa kata sandi hanya tersedia melalui koneksi aman.",
+    "Browser not supported" : "Peramban tidak didukung",
+    "Passwordless authentication is not supported in your browser." : "Otentikasi tanpa kata sandi tidak didukung peramban Anda.",
     "Reset password" : "Setel ulang kata sandi",
+    "Back to login" : "Kembali ke log masuk",
     "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim surel setel ulang. Silakan hubungi administrator Anda.",
     "Password cannot be changed. Please contact your administrator." : "Kata sandi tidak dapat diubah. Silakan hubungi administrator Anda.",
-    "Back to login" : "Kembali ke log masuk",
     "New password" : "Kata sandi baru",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Berkas Anda terenkripsi. Tidak memungkinkan untuk mendapatkan kembali data Anda setelah kata sandi disetel ulang. Jika tidak yakin, silakan hubungi administrator Anda sebelum melanjutkan. Apa Anda ingin melanjutkan?",
     "I know what I'm doing" : "Saya tahu apa yang saya lakukan",
     "Resetting password" : "Menyetel ulang kata sandi",
+    "Schedule work & meetings, synced with all your devices." : "Penjadwalan rapat & pekerjaan, tersinkronisasi dengan gawai Anda.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Simpan info teman dan kolega Anda dalam satu tempat, tanpa membocorkan privat mereka.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplikasi klien surel sederhana, terintegrasi dengan Berkas, Kontak, dan Kalender.",
     "Recommended apps" : "Aplikasi terekomendasi",
     "Loading apps …" : "Memuat aplikasi ...",
     "Could not fetch list of apps from the App Store." : "Tidak dapat mengambil daftar aplikasi dari App Store.",
-    "Installing apps …" : "menginstal aplikasi ...",
     "App download or installation failed" : "Unduh aplikasi atau gagal instalasi",
     "Cannot install this app because it is not compatible" : "Tidak dapat memasang aplikasi ini karena tidak kompatibel",
     "Cannot install this app" : "Tidak dapat memasang aplikasi ini",
     "Skip" : "Lewati",
+    "Installing apps …" : "menginstal aplikasi ...",
     "Install recommended apps" : "Instal aplikasi yang disarankan",
-    "Schedule work & meetings, synced with all your devices." : "Penjadwalan rapat & pekerjaan, tersinkronisasi dengan gawai Anda.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Simpan info teman dan kolega Anda dalam satu tempat, tanpa membocorkan privat mereka.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplikasi klien surel sederhana, terintegrasi dengan Berkas, Kontak, dan Kalender.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mengobrol, panggilan video, berbagi layar, rapat daring, dan konferensi web - melalui peramban dan menggunakan aplikasi pada gawai.",
+    "Settings menu" : "Menu Pengaturan",
+    "Loading your contacts …" : "Memuat kontak Anda ...",
+    "Looking for {term} …" : "Mencari {term}",
     "Reset search" : "Ulang pencarian",
     "Search contacts …" : "Cari kontak ...",
     "Could not load your contacts" : "Tidak dapat memuat kontak Anda",
     "No contacts found" : "Kontak tidak ditemukan",
     "Show all contacts" : "Tampilkan semua kontak",
     "Install the Contacts app" : "Instal aplikasi Kontak",
-    "Loading your contacts …" : "Memuat kontak Anda ...",
-    "Looking for {term} …" : "Mencari {term}",
-    "Search for {name} only" : "Cari {name} saja",
-    "Start typing to search" : "Mulai mengetik untuk mencari",
-    "Loading more results …" : "Memuat hasil lainnya…",
-    "Load more results" : "Muat lebih banyak hasil",
     "Search" : "Cari",
     "No results for {query}" : "Tidak ada hasil untuk {query}",
-    "An error occurred while searching for {type}" : "Terjadi kesalahan saat mencari {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Harap masukkan {minSearchLength} karakter atau lebih untuk mencari"],
+    "An error occurred while searching for {type}" : "Terjadi kesalahan saat mencari {type}",
+    "Search for {name} only" : "Cari {name} saja",
+    "Loading more results …" : "Memuat hasil lainnya…",
     "Forgot password?" : "Lupa kata sandi?",
     "Back" : "Kembali",
-    "Edit Profile" : "Sunting profil",
-    "You have not added any info yet" : "Anda belum menambahkan info apa pun",
-    "{user} has not added any info yet" : "{user} belum menambahkan info apa pun",
+    "Security warning" : "Peringatan keamanan",
+    "Storage & database" : "Penyimpanan & Basis data",
+    "Data folder" : "Folder data",
+    "Install and activate additional PHP modules to choose other database types." : "Pasang dan aktifkan modul PHP tambahan untuk memilih tipe basis data lainnya.",
+    "For more details check out the documentation." : "Untuk lebih rinci, periksa pada dokumentasi.",
+    "Performance warning" : "Peringatan kinerja",
+    "You chose SQLite as database." : "Anda memilih SQLite sebagai pangkalan data",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite hanya digunakan pada instalasi minimal dan lingkungan pengembangan. Untuk lingkungan produksi dianjurkan menggunakan backend pangkalan data lain.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jika menggunakan klien untuk sinkronisasi berkas, penggunaan SQLite sangat tidak dianjurkan.",
+    "Database user" : "Pengguna basis data",
+    "Database password" : "Kata sandi basis data",
+    "Database name" : "Nama basis data",
+    "Database tablespace" : "Tablespace basis data",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Harap tentukan nomor port beserta nama host (contoh., localhost:5432).",
+    "Database host" : "Host basis data",
+    "Installing …" : "Memasang …",
+    "Install" : "Pasang",
+    "Need help?" : "Butuh bantuan?",
+    "See the documentation" : "Lihat dokumentasi",
     "Search {types} …" : "Cari {types} …",
-    "Today" : "Hari ini",
-    "People" : "Orang",
-    "Settings menu" : "Menu Pengaturan",
-    "No" : "Tidak",
-    "Yes" : "Ya",
     "Choose" : "Pilih",
     "Copy" : "Salin",
     "Move" : "Pindah",
     "OK" : "OK",
-    "Error loading message template: {error}" : "Kesalahan memuat templat pesan: {error}",
     "read-only" : "hanya-baca",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} berkas konflik"],
     "One file conflict" : "Satu berkas konflik",
@@ -179,11 +190,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Ketik untuk mencari proyek eksis",
     "New in" : "Terbaru",
     "View changelog" : "Lihat log pembaruan",
-    "Very weak password" : "Kata sandi sangat lemah",
-    "Weak password" : "Kata sandi lemah",
-    "So-so password" : "Kata sandi lumayan",
-    "Good password" : "Kata sandi baik",
-    "Strong password" : "Kata sandi kuat",
     "No action available" : "Aksi tidak tersedia",
     "Error fetching contact actions" : "Galat mengambil aksi kontak",
     "Non-existing tag #{tag}" : "Tag tidak ada #{tag}",
@@ -194,19 +200,14 @@ OC.L10N.register(
     "Collaborative tags" : "Tag kolaboratif",
     "No tags found" : "Tag tidak ditemukan",
     "Personal" : "Pribadi",
-    "Users" : "Pengguna",
-    "Apps" : "Aplikasi",
     "Admin" : "Admin",
     "Help" : "Bantuan",
     "Access forbidden" : "Akses ditolak",
-    "Profile not found" : "Profil tidak ditemukan",
-    "The profile does not exist." : "Profil tidak ada.",
-    "Back to %s" : "Kembali ke %s",
     "Page not found" : "Halaman tidak ditemukan",
+    "Back to %s" : "Kembali ke %s",
     "Too many requests" : "Terlalu banyak permintaan",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ada terlalu banyak permintaan dari jaringan Anda. Coba lagi nanti atau hubungi administrator Anda jika ini adalah kesalahan.",
     "Error" : "Kesalahan",
-    "Previous" : "Sebelumnya",
     "Internal Server Error" : "Kesalahan Server Internal",
     "The server was unable to complete your request." : "Peladen tidak dapat menyelesaikan permintaan Anda.",
     "If this happens again, please send the technical details below to the server administrator." : "Jika terjadi lagi, silakan sampaikan detail di bawah kepada administrator.",
@@ -220,32 +221,6 @@ OC.L10N.register(
     "File: %s" : "Berkas: %s",
     "Line: %s" : "Baris: %s",
     "Trace" : "Jejak",
-    "Security warning" : "Peringatan keamanan",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas Anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informasi bagaimana kesesuaian konfigurasi peladen Anda, silakan lihat <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasi</a>.",
-    "Create an <strong>admin account</strong>" : "Buat sebuah <strong>akun admin</strong>",
-    "Username" : "Nama pengguna",
-    "Show password" : "Tampilkan kata sandi",
-    "Storage & database" : "Penyimpanan & Basis data",
-    "Data folder" : "Folder data",
-    "Configure the database" : "Konfigurasikan basis data",
-    "Only %s is available." : "Hanya %s yang tersedia",
-    "Install and activate additional PHP modules to choose other database types." : "Pasang dan aktifkan modul PHP tambahan untuk memilih tipe basis data lainnya.",
-    "For more details check out the documentation." : "Untuk lebih rinci, periksa pada dokumentasi.",
-    "Database user" : "Pengguna basis data",
-    "Database password" : "Kata sandi basis data",
-    "Database name" : "Nama basis data",
-    "Database tablespace" : "Tablespace basis data",
-    "Database host" : "Host basis data",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Harap tentukan nomor port beserta nama host (contoh., localhost:5432).",
-    "Performance warning" : "Peringatan kinerja",
-    "You chose SQLite as database." : "Anda memilih SQLite sebagai pangkalan data",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite hanya digunakan pada instalasi minimal dan lingkungan pengembangan. Untuk lingkungan produksi dianjurkan menggunakan backend pangkalan data lain.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jika menggunakan klien untuk sinkronisasi berkas, penggunaan SQLite sangat tidak dianjurkan.",
-    "Install" : "Pasang",
-    "Installing …" : "Memasang …",
-    "Need help?" : "Butuh bantuan?",
-    "See the documentation" : "Lihat dokumentasi",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sepertinya Anda coba untuk menginstal ulang Nextcloud. Namun berkas CAN_INSTALL tidak ditemukan pada direktori konfigurasi. Silakan buat berkas tersebut untuk melanjutkan.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Tidak dapat membuang CAN_INSTALL dari direktori konfigurasi. Silakan lakukan secara manual.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikasi ini memerlukan JavaScript untuk dapat beroperasi dengan benar. Mohon {linkstart}aktifkan JavaScript{linkend} dan muat ulang halaman ini.",
@@ -262,6 +237,7 @@ OC.L10N.register(
     "Account connected" : "Akun terhubung",
     "Your client should now be connected!" : "Klien sudah terhubung!",
     "You can close this window." : "Anda dapat menutup jendela ini.",
+    "Previous" : "Sebelumnya",
     "This share is password-protected" : "Berbagi ini dilindungi kata sandi",
     "Please type in your email address to request a temporary password" : "Silakan ketik alamat surel Anda untuk meminta kata sandi sementara",
     "Email address" : "Alamat surel",
@@ -291,7 +267,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Untuk menghindari waktu habis dengan instalasi yang lebih besar, Anda bisa menjalankan perintah berikut dari direktori instalasi Anda:",
     "Detailed logs" : "Log detail",
     "Update needed" : "Pembaruan dibutuhkan",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Silakan gunakan command line updater, karena instalasi Anda memiliki pengguna lebih dari 50.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Lihat <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasi</a> untuk panduan.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Saya paham jika melakukan proses pemutakhiran via antarmuka web, berisiko komunikasi terhenti dan kemungkinan kehilangan data. Saya punya cadangan dan paham bagaimana cara pemulihan, jika terjadi kegagalan.",
     "Upgrade via web on my own risk" : "Pemutakhiran via web adalah risiko saya",
@@ -299,54 +274,22 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
     "This page will refresh itself when the instance is available again." : "Laman ini akan dimuat otomatis saat instalasi kembali tersedia.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem Anda jika pesan ini terus muncul atau muncul tiba-tiba.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP tidak disetel sesuai untuk melakukan kueri system environment variables. Pengujian dengan getenv(\"PATH\") hanya menghasilkan pesan kosong. ",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurasi baca-saja telah diaktifkan. Hal ini mencegah penyetelan beberapa konfigurasi via antarmuka web. Pada setiap proses pembaruan berikutnya, secara manual berkas tersebut perlu dibuat agar dapat ditulis.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Database Anda tidak dijalankan dengan isolasi transaksi level \"READ COMMITED\". Ini dapat menyebabkan masalah saat banyak tindakan dilakukan secara paralel.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Modul PHP \"fileinfo\" tidak ditemukan. Sangat dianjurkan untuk mengaktifkan modul ini, agar mendapatkan hasil deteksi terbaik tipe MIME. ",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Tidak memungkinan untuk eksekusi cron job via CLI. Kesalahan teknis berikut muncul:",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Anda sedang menjalankan PHP {version}. Tingkatkan versi PHP Anda untuk memanfaatkan kinerja {linkstart} dan pembaruan keamanan yang disediakan oleh Grup PHP ↗{linkend} segera setelah distribusi Anda mendukungnya.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Fungsi PHP \"set_time_limit\" tidak tersedia. Hal ini dapat menyebabkan instalasi Anda, akibat eksekusi skrip terhenti ditengah-tengah. Mengaktifkan fungsi ini sangat dianjurkan.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP Anda tidak mendukung FreeType, yang akan menyebabkan gangguan pada foto profil dan pengaturan antarmuka.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Tidak ada index \"{indexName}\" pada tabel \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Pangkalan data kehilangan beberapa indeks. Berdasarkan fakta bahwa menambahkan indeks pada tabel yang besar membutuhkan waktu cukup lama, maka ini tidak dilakukan otomatis. Eksekusi \"occ db: add-missing-indexes\", untuk menambahkan indeks secara manual sementara instance tetap berjalan. Setelah itu dilakukan, maka kueri akan jauh lebih cepat.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Tidak ditemukan kolom opsional \"{columnName}\" pada tabel \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Pangkalan data kehilangan beberapa kolom opsional. Berdasarkan fakta bahwa menambahkannya pada tabel yang besar membutuhkan waktu cukup lama, maka ini tidak dilakukan otomatis. Eksekusi \"occ db: add-missing-columns\", untuk menambahkan kolom secara manual sementara instance tetap berjalan. Setelah itu dilakukan, maka beberapa fitur dapat meningkatkan daya tanggap atau kegunaan.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instance ini kehilangan beberapa modul PHP yang direkomendasikan. Sangat disarankan menggunakannya untuk peningkatan performa dan kompatibilitas.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite saat ini digunakan sebagai backend pangkalan data. Penggunaan instalasi skala lebih besar, kami sarankan agar beralih ke backend pangkalan data lainnya.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Hal ini sangat dianjurkan saat menggunakan klien desktop untuk sinkronisasi berkas.",
-    "The PHP memory limit is below the recommended value of 512MB." : "Batas memori PHP di bawah nilai yang disarankan yaitu 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Beberapa direktori dimiliki oleh pengguna berbeda dengan pengguna peladen web. Hal ini mungkin dikarenakan proses instalasi manual. Periksa hak akses direktori aplikasi berikut:",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Instance ini menggunakan penyimpanan objek berbasis S3 sebagai penyimpanan utama. Karena berkas unggahan disimpan sementara pada server, maka disarankan untuk memiliki ruang kosong 50 GB pada direktori sementara PHP. Periksa log untuk detail lengkap tentang lokasi dan ruang penyimpanan yang tersedia. Untuk memperbaikinya, ubah direktori sementara di php.ini atau sediakan lebih banyak ruang di jalur ipada lokasi tersebut.",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Pesan pengaturan ulang kata sandi telah dikirim ke alamat surel akun ini. Jika Anda tidak menerimanya, periksa folder spam/sampah Anda atau minta bantuan administrator lokal Anda.",
-    "If it is not there ask your local administrator." : "Jika Anda tidak mendapatkannya, hubungi administrator Anda.",
-    "Start search" : "Mulai mencari",
-    "Press enter to start searching" : "Tekan enter untuk mulai mencari",
-    "Settings" : "Pengaturan",
-    "Show all contacts …" : "Tampilkan semua kontak ...",
-    "No files in here" : "Tidak ada berkas di sini",
-    "New folder" : "Folder baru",
-    "No more subfolders in here" : "Tidak ada lagi subfolder di sini",
-    "Name" : "Nama",
-    "Size" : "Ukuran",
-    "Modified" : "Dimodifikasi",
-    "\"{name}\" is an invalid file name." : "\"{name}\" adalah nama berkas yang tidak sah.",
-    "File name cannot be empty." : "Nama berkas tidak boleh kosong.",
-    "\"/\" is not allowed inside a file name." : "\"/\" tidak diizinkan pada nama berkas.",
-    "\"{name}\" is not an allowed filetype" : "Tipe berkas \"{name}\" tidak diizinkan",
-    "{newName} already exists" : "{newName} sudah ada",
-    "Error loading file picker template: {error}" : "Kesalahan saat memuat templat berkas pemilih: {error}",
-    "Show list view" : "Tampilkan sebagai daftar",
-    "Show grid view" : "Tampilkan sebagai kisi",
-    "Pending" : "Terutnda",
-    "Home" : "Beranda",
-    "Copy to {folder}" : "Salin ke {folder}",
-    "Move to {folder}" : "Pindah ke {folder}",
-    "Authentication required" : "Diperlukan otentikasi",
-    "This action requires you to confirm your password" : "Aksi ini membutuhkan konfirmasi kata sandi Anda",
-    "Confirm" : "Konfirmasi",
-    "Failed to authenticate, try again" : "Gagal mengotentikasi, coba lagi",
-    "Confirm your password" : "Konfirmasi kata sandi Anda",
-    "App token" : "Token aplikasi",
-    "Alternative log in using app token" : "Log masuk alternatif dengan token aplikasi"
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mengobrol, panggilan video, berbagi layar, rapat daring, dan konferensi web - melalui peramban dan menggunakan aplikasi pada gawai.",
+    "You have not added any info yet" : "Anda belum menambahkan info apa pun",
+    "{user} has not added any info yet" : "{user} belum menambahkan info apa pun",
+    "Edit Profile" : "Sunting profil",
+    "Error loading message template: {error}" : "Kesalahan memuat templat pesan: {error}",
+    "Very weak password" : "Kata sandi sangat lemah",
+    "Weak password" : "Kata sandi lemah",
+    "So-so password" : "Kata sandi lumayan",
+    "Good password" : "Kata sandi baik",
+    "Strong password" : "Kata sandi kuat",
+    "Profile not found" : "Profil tidak ditemukan",
+    "The profile does not exist." : "Profil tidak ada.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas Anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informasi bagaimana kesesuaian konfigurasi peladen Anda, silakan lihat <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasi</a>.",
+    "Show password" : "Tampilkan kata sandi",
+    "Configure the database" : "Konfigurasikan basis data",
+    "Only %s is available." : "Hanya %s yang tersedia"
 },
 "nplurals=1; plural=0;");
