@@ -80,35 +80,38 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} notificacion","{count} notificacions"],
     "No" : "No",
     "Yes" : "Yes",
-    "Date" : "Data",
-    "Today" : "Uèi",
-    "People" : "Gent",
-    "Load more results" : "Cargar mai de resultats",
     "Searching …" : "Recèrca…",
     "Start typing to search" : "Començatz de picar per recercar",
+    "Today" : "Uèi",
+    "Date" : "Data",
+    "People" : "Gent",
+    "Load more results" : "Cargar mai de resultats",
     "Log in" : "Connexion",
     "Logging in …" : "Identificacion…",
+    "Log in to {productName}" : "Se connectar a {productName}",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
+    "Account name or email" : "Nom d’utilizaire o email",
     "Server side authentication failed!" : "Autentificacion costat servidor fracassada !",
     "Please contact your administrator." : "Mercés de contactar vòstre administrator.",
     "An internal error occurred." : "Una error intèrna s’es producha.",
     "Please try again or contact your administrator." : "Tornatz ensajar o contactatz vòstre administrator.",
     "Password" : "Senhal",
-    "Log in to {productName}" : "Se connectar a {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
-    "Account name or email" : "Nom d’utilizaire o email",
     "Log in with a device" : "Connexion amb un periferic",
     "Your account is not setup for passwordless login." : "Vòstre compte es pas parametrat per una autentificacion sens senhal.",
-    "Browser not supported" : "Navegador pas pres en carga",
-    "Passwordless authentication is not supported in your browser." : "L’autentificacion sens senhal es pas presa en cargar per vòstre navegador.",
     "Your connection is not secure" : "Vòstra connexion es pas segura",
     "Passwordless authentication is only available over a secure connection." : "L’autentificacion sens senhal es sonque disponibla via una connexion segura.",
+    "Browser not supported" : "Navegador pas pres en carga",
+    "Passwordless authentication is not supported in your browser." : "L’autentificacion sens senhal es pas presa en cargar per vòstre navegador.",
     "Reset password" : "Reïnicializar senhal",
+    "Back to login" : "Tornar a la connexion",
     "Couldn't send reset email. Please contact your administrator." : "Impossible de mandar lo corrièl de reïnicializacion. Contactatz vòstre administrator.",
     "Password cannot be changed. Please contact your administrator." : "Se pòt pas cambiar lo senhal. Mercés de contactar vòstre administrator.",
-    "Back to login" : "Tornar a la connexion",
     "New password" : "Senhal novèl",
     "I know what I'm doing" : "Sabi çò que fau",
     "Resetting password" : "Reïnicializacion de senhal",
+    "Schedule work & meetings, synced with all your devices." : "Planificatz prètzfaches e reünions, sincronizats amb totes vòstres periferics.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Gardatz vòstres companhs e amics a un sòl lòc sens divulgar lor vida privada.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicacion simpla e simpatica de corrièl integrada a Fichièrs, Contactes e Calendièr.",
     "Recommended apps" : "Aplicacions recomandadas",
     "Loading apps …" : "Cargament aplicacions…",
     "App download or installation failed" : "Telecargament o installacion de l’aplicacion fracassada",
@@ -117,31 +120,46 @@ OC.L10N.register(
     "Skip" : "Sautar",
     "Installing apps …" : "Installacion aplicacions…",
     "Install recommended apps" : "Installar las aplicacions recomandadas",
-    "Schedule work & meetings, synced with all your devices." : "Planificatz prètzfaches e reünions, sincronizats amb totes vòstres periferics.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Gardatz vòstres companhs e amics a un sòl lòc sens divulgar lor vida privada.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicacion simpla e simpatica de corrièl integrada a Fichièrs, Contactes e Calendièr.",
     "Settings menu" : "Menú paramètres",
+    "Loading your contacts …" : "Cargaments dels contactes…",
+    "Looking for {term} …" : "Recèrca de {term}…",
     "Search contacts" : "Cercar pels contactes",
     "Reset search" : "Escafar la recèrca",
     "Search contacts …" : "Cercar pels contactes…",
     "Could not load your contacts" : "Cargament impossible de vòstres contactes",
     "No contacts found" : "Cap de contact pas trobat",
     "Install the Contacts app" : "Installar l’aplicacion Contactes",
-    "Loading your contacts …" : "Cargaments dels contactes…",
-    "Looking for {term} …" : "Recèrca de {term}…",
-    "Search for {name} only" : "Cercar sonque {name}",
-    "Loading more results …" : "Cargament de mai de resultats…",
     "Search" : "Recercar",
     "No results for {query}" : "Cap de resultat per {query}",
     "An error occurred while searching for {type}" : "Una error s’es producha en cercant {type}",
+    "Search for {name} only" : "Cercar sonque {name}",
+    "Loading more results …" : "Cargament de mai de resultats…",
     "Forgot password?" : "Senhal oblidat ?",
     "Back" : "Retorn",
     "Login form is disabled." : "Lo formulari de connexion es desactivat.",
-    "Edit Profile" : "Modificar perfil",
     "More actions" : "Mai d’accions",
+    "Security warning" : "Avertiment de seguretat",
+    "Storage & database" : "Emmagazinatge & basa de donada",
+    "Data folder" : "Dossièr de donadas",
+    "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
+    "For more details check out the documentation." : "Per mai de detalhs consultatz la documentacion.",
+    "Performance warning" : "Avertiment de performança",
+    "You chose SQLite as database." : "Causissètz SQLite coma basa de donadas.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite deu solament èsser utilizat per d’instàncias minimalas e de desvolopament. Per la produccion recomandam un autre sistèma de basa de donadas.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "S’utilizatz los clients per sincronizar de fichièrs, l’utilizacion de SQLite es forçadament descoratjada.",
+    "Database user" : "Utilizaire basa de donadas",
+    "Database password" : "Senhal basa de donadas",
+    "Database name" : "Nom basa de donadas",
+    "Database tablespace" : "Tablespace basa de donadas",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Volgatz especificar lo numèro de pòrt aprèp lo nom d’òste (ex : localhost:5432).",
+    "Database host" : "Òste basa de donadas",
+    "Installing …" : "Installacion...",
+    "Install" : "Installar",
+    "Need help?" : "Besonh d’ajuda ?",
+    "See the documentation" : "Vejatz la documentacion",
+    "{name} version {version} and above" : "{name} version {version} e ulterior",
     "This browser is not supported" : "Aqueste navigador es pas pres en carga",
     "Supported versions" : "Versions presas en carga",
-    "{name} version {version} and above" : "{name} version {version} e ulterior",
     "Search {types} …" : "Recèrca {types}…",
     "Choose" : "Causir",
     "Copy" : "Copiar",
@@ -172,11 +190,6 @@ OC.L10N.register(
     "Connect items to a project to make them easier to find" : "Connectatz d’elements a un projècte per lo rendre mai simples de trobar",
     "New in" : "Nòu dins",
     "View changelog" : "Veire jornal de modificacions",
-    "Very weak password" : "Senhal plan feble",
-    "Weak password" : "Senhal feble",
-    "So-so password" : "Senhal mejan",
-    "Good password" : "Bon senhal",
-    "Strong password" : "Senhal fòrt",
     "No action available" : "Cap d’accion pas disponibla",
     "Error fetching contact actions" : "Error en recuperacion las accions contacte",
     "Non-existing tag #{tag}" : "Etiqueta inexistenta #{tag}",
@@ -190,14 +203,11 @@ OC.L10N.register(
     "Admin" : "Admin",
     "Help" : "Ajuda",
     "Access forbidden" : "Accès defendut",
-    "Profile not found" : "Perfil pas trobat",
-    "The profile does not exist." : "Lo perfil existís pas.",
-    "Back to %s" : "Tornar a %s",
     "Page not found" : "Pagina pas trobada",
+    "Back to %s" : "Tornar a %s",
     "Too many requests" : "Tròp de requèstas",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "I a agut tròp de requèstas a partir de vòstre ret. Tornatz ensajar mai tard o contactatz vòstre administrator s’aquò es una error.",
     "Error" : "Error",
-    "Previous" : "Precedent",
     "Internal Server Error" : "Error intèrna del servidor",
     "The server was unable to complete your request." : "Lo servidor a pas pogut terminar vòstra requèsta.",
     "If this happens again, please send the technical details below to the server administrator." : "S’aquò tòrna arribar, enviatz lo detalhs tecnics çai-jos a l’administrator del servidor.",
@@ -211,31 +221,6 @@ OC.L10N.register(
     "File: %s" : "Fichièr : %s",
     "Line: %s" : "Linha : %s",
     "Trace" : "Traça",
-    "Security warning" : "Avertiment de seguretat",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas e vòstres fichièrs son probablament accessibles a partir d’internet pr’amor que lo fichièr .htaccess fonciona pas.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per d’informacions per corrèctament configurar vòstre servidor, consultatz la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentacion</a>.",
-    "Create an <strong>admin account</strong>" : "Crear un <strong>compte admin</strong>",
-    "Show password" : "Mostrar lo senhal",
-    "Toggle password visibility" : "Alternar la visibilitat del senhal",
-    "Storage & database" : "Emmagazinatge & basa de donada",
-    "Data folder" : "Dossièr de donadas",
-    "Configure the database" : "Configurar la basa de donadas",
-    "Only %s is available." : "Sonque %s es disponible.",
-    "Install and activate additional PHP modules to choose other database types." : "Installatz e activatz los modules PHP complementaris per causir d’autres tipes de basas de donadas.",
-    "For more details check out the documentation." : "Per mai de detalhs consultatz la documentacion.",
-    "Database password" : "Senhal basa de donadas",
-    "Database name" : "Nom basa de donadas",
-    "Database tablespace" : "Tablespace basa de donadas",
-    "Database host" : "Òste basa de donadas",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Volgatz especificar lo numèro de pòrt aprèp lo nom d’òste (ex : localhost:5432).",
-    "Performance warning" : "Avertiment de performança",
-    "You chose SQLite as database." : "Causissètz SQLite coma basa de donadas.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite deu solament èsser utilizat per d’instàncias minimalas e de desvolopament. Per la produccion recomandam un autre sistèma de basa de donadas.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "S’utilizatz los clients per sincronizar de fichièrs, l’utilizacion de SQLite es forçadament descoratjada.",
-    "Install" : "Installar",
-    "Installing …" : "Installacion...",
-    "Need help?" : "Besonh d’ajuda ?",
-    "See the documentation" : "Vejatz la documentacion",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembla que sètz a reïnstallar vòstre Nextcloud. Pasmens lo fichièr CAN_INSTALL es absent del repertòri config. Volgatz ben crear lo fichièr CAN_INSTALL dins vòstre dossièr config per contunhar.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Supression impossibla de CAN_INSTALL dins lo repertòri config. Mercés de lo tirar manualament.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicacion requerís JavaScript per foncionar coma cal. {linkstart}Activatz JavaScript{linkend} e recargatz la pagina.",
@@ -247,12 +232,14 @@ OC.L10N.register(
     "Please log in before granting %1$s access to your %2$s account." : "Autentificatz-vos abans de donnar l’accès a %1$s a vòstre compte %2$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se ensajatz pas de configurar un periferic novèl o una aplicacion novèla, qualqu’un ensaja de vos far donar accès a vòstras donadas. En aqueste cas, contunhetz pas e contactatz vòstre administrator sistèma.",
     "Grant access" : "Donar accès",
+    "Alternative log in using app password" : "Connexion alternativa en utilizant un senhal d’aplicacion",
     "Account access" : "Accès compte",
     "Currently logged in as %1$s (%2$s)." : "Actualament connectat coma %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s.",
     "Account connected" : "Compte connectat",
     "Your client should now be connected!" : "Vòstre client deu èsser connectat ara !",
     "You can close this window." : "Podètz tampar aquesta fenèstra.",
+    "Previous" : "Precedent",
     "This share is password-protected" : "Aqueste partiment es protegit per un senhal",
     "Email address" : "Adreça mail",
     "Password sent!" : "Senhal enviat !",
@@ -285,23 +272,23 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "L’instància %s es actualament en mòde manteniment, pòt trigar.",
     "This page will refresh itself when the instance is available again." : "Aquesta pagina s’actualizarà soleta quand l’instància serà disponibla de nòu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactatz l’administrator sistèma s’aqueste messatge ten d’aparéisser o apareis sens rason.",
-    "The user limit of this instance is reached." : "Lo limit d’utilizaires d’aquesta instància es atengut.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Sembla que vòstre servidor es pas configurat corrèctament per permetre la sincronizacion de fichièrs, perque l’interfàcia WebDAV sembla copada.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » es pas definida a « {expected} ». Aquò es un risc de seguretat o de vida privada, es recomandat d’ajustar aqueste paramètre en consequéncia.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » es pas definida a « {expected} ». D’unas foncionalitats poirián foncionar pas corrèctament, es recomandat d’ajustar aqueste paramètre en consequéncia.",
     "Currently open" : "Actualament dobèrta",
-    "Wrong username or password." : "Marrit nom d’utilizaire o senhal.",
-    "User disabled" : "Utilizaire desactivat",
-    "Username or email" : "Nom d’utilizaire o senhal",
+    "Login with username or email" : "Connexion amb nom d’utilizaire o email",
+    "Login with username" : "Connexion amb nom d’utilizaire",
+    "Edit Profile" : "Modificar perfil",
     "Error loading message template: {error}" : "Error de cargament del modèl de messatge : {error}",
-    "Users" : "Utilizaires",
-    "Username" : "Nom d'utilizaire",
-    "Database user" : "Utilizaire basa de donadas",
-    "This action requires you to confirm your password" : "Aquesta accions vos demanda de confirmar vòstre senhal",
-    "Confirm your password" : "Confirmatz lo senhal",
-    "Confirm" : "Confirmar",
-    "App token" : "Geton aplicacion",
-    "Alternative log in using app token" : "Autentificacion alternativa en utilizant un geton d’aplicacion",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Mercés d’utilizar l’aisina de mesa a jorn en linha de comanda s’avètz una brava instància de mai de 50 utilizaires."
+    "Very weak password" : "Senhal plan feble",
+    "Weak password" : "Senhal feble",
+    "So-so password" : "Senhal mejan",
+    "Good password" : "Bon senhal",
+    "Strong password" : "Senhal fòrt",
+    "Profile not found" : "Perfil pas trobat",
+    "The profile does not exist." : "Lo perfil existís pas.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vòstre repertòri de donadas e vòstres fichièrs son probablament accessibles a partir d’internet pr’amor que lo fichièr .htaccess fonciona pas.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per d’informacions per corrèctament configurar vòstre servidor, consultatz la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentacion</a>.",
+    "Show password" : "Mostrar lo senhal",
+    "Toggle password visibility" : "Alternar la visibilitat del senhal",
+    "Configure the database" : "Configurar la basa de donadas",
+    "Only %s is available." : "Sonque %s es disponible."
 },
 "nplurals=2; plural=(n > 1);");
