@@ -5,18 +5,19 @@ OC.L10N.register(
     "Invalid image" : "ບໍ່ມີຮູບພາບ",
     "Files" : "ຟາຍ",
     "seconds ago" : "ວິນາທີຜ່ານມາ",
+    "Filename contains at least one invalid character" : "ຊື່ຟາຍມີລັກສະນະທີ່ບໍ່ຖືກຕ້ອງ",
     "__language_name__" : "ຂີ້ຕົວະ",
     "Apps" : "ແອັບພລິເຄຊັນ",
     "Settings" : "ການຕັ້ງຄ່າ",
     "Log out" : "ອອກຈາກລະບົບ",
-    "Users" : "ຜູ້ໃຊ້",
+    "Accounts" : "ບັນຊີ",
     "Email" : "ອິເມວ",
     "Twitter" : "Twitter",
     "Website" : "ເວັບໄຊ",
     "Address" : "ທີ່ຢູ່",
     "About" : "ກ່ຽວກັບ",
     "Role" : "ພາລະບົດບາດ",
-    "Help" : "ການຊ່ວຍເຫຼືອ",
-    "User disabled" : "ປິດຊື່ຜູ້ໃຊ້"
+    "Translate" : "ແປ",
+    "Users" : "ຜູ້ໃຊ້"
 },
 "nplurals=1; plural=0;");
